// Code generated by 'yaegi extract syscall'. DO NOT EDIT.

//go:build go1.21 && !go1.22
// +build go1.21,!go1.22

package syscall

import (
	"go/constant"
	"go/token"
	"reflect"
	"syscall"
)

func init() {
	Symbols["syscall/syscall"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"AF_APPLETALK":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"AF_BLUETOOTH":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"AF_CCITT":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"AF_CHAOS":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"AF_CNT":                            reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"AF_COIP":                           reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"AF_DATAKIT":                        reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"AF_DECnet":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"AF_DLI":                            reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"AF_E164":                           reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"AF_ECMA":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"AF_ENCAP":                          reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"AF_HYLINK":                         reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"AF_IMPLINK":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"AF_INET":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AF_INET6":                          reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"AF_IPX":                            reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"AF_ISDN":                           reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"AF_ISO":                            reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_KEY":                            reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"AF_LAT":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"AF_LINK":                           reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"AF_LOCAL":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_MAX":                            reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"AF_MPLS":                           reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"AF_NATM":                           reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"AF_NS":                             reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"AF_OSI":                            reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_PUP":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"AF_ROUTE":                          reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"AF_SIP":                            reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"AF_SNA":                            reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"AF_UNIX":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_UNSPEC":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ARPHRD_ETHER":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ARPHRD_FRELAY":                     reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"ARPHRD_IEEE1394":                   reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"ARPHRD_IEEE802":                    reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"Accept":                            reflect.ValueOf(syscall.Accept),
		"Accept4":                           reflect.ValueOf(syscall.Accept4),
		"Access":                            reflect.ValueOf(syscall.Access),
		"Adjtime":                           reflect.ValueOf(syscall.Adjtime),
		"B0":                                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"B110":                              reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"B115200":                           reflect.ValueOf(constant.MakeFromLiteral("115200", token.INT, 0)),
		"B1200":                             reflect.ValueOf(constant.MakeFromLiteral("1200", token.INT, 0)),
		"B134":                              reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"B14400":                            reflect.ValueOf(constant.MakeFromLiteral("14400", token.INT, 0)),
		"B150":                              reflect.ValueOf(constant.MakeFromLiteral("150", token.INT, 0)),
		"B1800":                             reflect.ValueOf(constant.MakeFromLiteral("1800", token.INT, 0)),
		"B19200":                            reflect.ValueOf(constant.MakeFromLiteral("19200", token.INT, 0)),
		"B200":                              reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"B230400":                           reflect.ValueOf(constant.MakeFromLiteral("230400", token.INT, 0)),
		"B2400":                             reflect.ValueOf(constant.MakeFromLiteral("2400", token.INT, 0)),
		"B28800":                            reflect.ValueOf(constant.MakeFromLiteral("28800", token.INT, 0)),
		"B300":                              reflect.ValueOf(constant.MakeFromLiteral("300", token.INT, 0)),
		"B38400":                            reflect.ValueOf(constant.MakeFromLiteral("38400", token.INT, 0)),
		"B4800":                             reflect.ValueOf(constant.MakeFromLiteral("4800", token.INT, 0)),
		"B50":                               reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"B57600":                            reflect.ValueOf(constant.MakeFromLiteral("57600", token.INT, 0)),
		"B600":                              reflect.ValueOf(constant.MakeFromLiteral("600", token.INT, 0)),
		"B7200":                             reflect.ValueOf(constant.MakeFromLiteral("7200", token.INT, 0)),
		"B75":                               reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"B76800":                            reflect.ValueOf(constant.MakeFromLiteral("76800", token.INT, 0)),
		"B9600":                             reflect.ValueOf(constant.MakeFromLiteral("9600", token.INT, 0)),
		"BIOCFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("536887912", token.INT, 0)),
		"BIOCGBLEN":                         reflect.ValueOf(constant.MakeFromLiteral("1074020966", token.INT, 0)),
		"BIOCGDIRFILT":                      reflect.ValueOf(constant.MakeFromLiteral("1074020988", token.INT, 0)),
		"BIOCGDLT":                          reflect.ValueOf(constant.MakeFromLiteral("1074020970", token.INT, 0)),
		"BIOCGDLTLIST":                      reflect.ValueOf(constant.MakeFromLiteral("3221766779", token.INT, 0)),
		"BIOCGETIF":                         reflect.ValueOf(constant.MakeFromLiteral("1075855979", token.INT, 0)),
		"BIOCGFILDROP":                      reflect.ValueOf(constant.MakeFromLiteral("1074020984", token.INT, 0)),
		"BIOCGHDRCMPLT":                     reflect.ValueOf(constant.MakeFromLiteral("1074020980", token.INT, 0)),
		"BIOCGRSIG":                         reflect.ValueOf(constant.MakeFromLiteral("1074020979", token.INT, 0)),
		"BIOCGRTIMEOUT":                     reflect.ValueOf(constant.MakeFromLiteral("1074545262", token.INT, 0)),
		"BIOCGSTATS":                        reflect.ValueOf(constant.MakeFromLiteral("1074283119", token.INT, 0)),
		"BIOCIMMEDIATE":                     reflect.ValueOf(constant.MakeFromLiteral("2147762800", token.INT, 0)),
		"BIOCLOCK":                          reflect.ValueOf(constant.MakeFromLiteral("536887926", token.INT, 0)),
		"BIOCPROMISC":                       reflect.ValueOf(constant.MakeFromLiteral("536887913", token.INT, 0)),
		"BIOCSBLEN":                         reflect.ValueOf(constant.MakeFromLiteral("3221504614", token.INT, 0)),
		"BIOCSDIRFILT":                      reflect.ValueOf(constant.MakeFromLiteral("2147762813", token.INT, 0)),
		"BIOCSDLT":                          reflect.ValueOf(constant.MakeFromLiteral("2147762810", token.INT, 0)),
		"BIOCSETF":                          reflect.ValueOf(constant.MakeFromLiteral("2148024935", token.INT, 0)),
		"BIOCSETIF":                         reflect.ValueOf(constant.MakeFromLiteral("2149597804", token.INT, 0)),
		"BIOCSETWF":                         reflect.ValueOf(constant.MakeFromLiteral("2148024951", token.INT, 0)),
		"BIOCSFILDROP":                      reflect.ValueOf(constant.MakeFromLiteral("2147762809", token.INT, 0)),
		"BIOCSHDRCMPLT":                     reflect.ValueOf(constant.MakeFromLiteral("2147762805", token.INT, 0)),
		"BIOCSRSIG":                         reflect.ValueOf(constant.MakeFromLiteral("2147762802", token.INT, 0)),
		"BIOCSRTIMEOUT":                     reflect.ValueOf(constant.MakeFromLiteral("2148287085", token.INT, 0)),
		"BIOCVERSION":                       reflect.ValueOf(constant.MakeFromLiteral("1074020977", token.INT, 0)),
		"BPF_A":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_ABS":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_ADD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_ALIGNMENT":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"BPF_ALU":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"BPF_AND":                           reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"BPF_B":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_DIRECTION_IN":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_DIRECTION_OUT":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"BPF_DIV":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_H":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BPF_IMM":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_IND":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_JA":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_JEQ":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_JGE":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_JGT":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_JMP":                           reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"BPF_JSET":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_K":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LD":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LDX":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_LEN":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_LSH":                           reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MAJOR_VERSION":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MAXBUFSIZE":                    reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"BPF_MAXINSNS":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"BPF_MEM":                           reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MEMWORDS":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_MINBUFSIZE":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_MINOR_VERSION":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MISC":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"BPF_MSH":                           reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"BPF_MUL":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_NEG":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_OR":                            reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_RELEASE":                       reflect.ValueOf(constant.MakeFromLiteral("199606", token.INT, 0)),
		"BPF_RET":                           reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"BPF_RSH":                           reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"BPF_ST":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"BPF_STX":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"BPF_SUB":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_TAX":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_TXA":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_W":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_X":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BRKINT":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Bind":                              reflect.ValueOf(syscall.Bind),
		"BpfBuflen":                         reflect.ValueOf(syscall.BpfBuflen),
		"BpfDatalink":                       reflect.ValueOf(syscall.BpfDatalink),
		"BpfHeadercmpl":                     reflect.ValueOf(syscall.BpfHeadercmpl),
		"BpfInterface":                      reflect.ValueOf(syscall.BpfInterface),
		"BpfJump":                           reflect.ValueOf(syscall.BpfJump),
		"BpfStats":                          reflect.ValueOf(syscall.BpfStats),
		"BpfStmt":                           reflect.ValueOf(syscall.BpfStmt),
		"BpfTimeout":                        reflect.ValueOf(syscall.BpfTimeout),
		"BytePtrFromString":                 reflect.ValueOf(syscall.BytePtrFromString),
		"ByteSliceFromString":               reflect.ValueOf(syscall.ByteSliceFromString),
		"CFLUSH":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"CLOCAL":                            reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"CREAD":                             reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"CS5":                               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CS6":                               reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"CS7":                               reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"CS8":                               reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"CSIZE":                             reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"CSTART":                            reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"CSTATUS":                           reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"CSTOP":                             reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"CSTOPB":                            reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"CSUSP":                             reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"CTL_MAXNAME":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"CTL_NET":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"Chdir":                             reflect.ValueOf(syscall.Chdir),
		"CheckBpfVersion":                   reflect.ValueOf(syscall.CheckBpfVersion),
		"Chflags":                           reflect.ValueOf(syscall.Chflags),
		"Chmod":                             reflect.ValueOf(syscall.Chmod),
		"Chown":                             reflect.ValueOf(syscall.Chown),
		"Chroot":                            reflect.ValueOf(syscall.Chroot),
		"Clearenv":                          reflect.ValueOf(syscall.Clearenv),
		"Close":                             reflect.ValueOf(syscall.Close),
		"CloseOnExec":                       reflect.ValueOf(syscall.CloseOnExec),
		"CmsgLen":                           reflect.ValueOf(syscall.CmsgLen),
		"CmsgSpace":                         reflect.ValueOf(syscall.CmsgSpace),
		"Connect":                           reflect.ValueOf(syscall.Connect),
		"DIOCOSFPFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("536888398", token.INT, 0)),
		"DLT_ARCNET":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"DLT_ATM_RFC1483":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"DLT_AX25":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"DLT_CHAOS":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"DLT_C_HDLC":                        reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"DLT_EN10MB":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DLT_EN3MB":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DLT_ENC":                           reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"DLT_FDDI":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"DLT_IEEE802":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"DLT_IEEE802_11":                    reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"DLT_IEEE802_11_RADIO":              reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"DLT_LOOP":                          reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"DLT_MPLS":                          reflect.ValueOf(constant.MakeFromLiteral("219", token.INT, 0)),
		"DLT_NULL":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"DLT_PFLOG":                         reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"DLT_PFSYNC":                        reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"DLT_PPP":                           reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"DLT_PPP_BSDOS":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"DLT_PPP_ETHER":                     reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"DLT_PPP_SERIAL":                    reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"DLT_PRONET":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"DLT_RAW":                           reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"DLT_SLIP":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"DLT_SLIP_BSDOS":                    reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"DT_BLK":                            reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"DT_CHR":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DT_DIR":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"DT_FIFO":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DT_LNK":                            reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"DT_REG":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"DT_SOCK":                           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"DT_UNKNOWN":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Dup":                               reflect.ValueOf(syscall.Dup),
		"Dup2":                              reflect.ValueOf(syscall.Dup2),
		"E2BIG":                             reflect.ValueOf(syscall.E2BIG),
		"EACCES":                            reflect.ValueOf(syscall.EACCES),
		"EADDRINUSE":                        reflect.ValueOf(syscall.EADDRINUSE),
		"EADDRNOTAVAIL":                     reflect.ValueOf(syscall.EADDRNOTAVAIL),
		"EAFNOSUPPORT":                      reflect.ValueOf(syscall.EAFNOSUPPORT),
		"EAGAIN":                            reflect.ValueOf(syscall.EAGAIN),
		"EALREADY":                          reflect.ValueOf(syscall.EALREADY),
		"EAUTH":                             reflect.ValueOf(syscall.EAUTH),
		"EBADF":                             reflect.ValueOf(syscall.EBADF),
		"EBADRPC":                           reflect.ValueOf(syscall.EBADRPC),
		"EBUSY":                             reflect.ValueOf(syscall.EBUSY),
		"ECANCELED":                         reflect.ValueOf(syscall.ECANCELED),
		"ECHILD":                            reflect.ValueOf(syscall.ECHILD),
		"ECHO":                              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"ECHOCTL":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ECHOE":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ECHOK":                             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ECHOKE":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ECHONL":                            reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ECHOPRT":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ECONNABORTED":                      reflect.ValueOf(syscall.ECONNABORTED),
		"ECONNREFUSED":                      reflect.ValueOf(syscall.ECONNREFUSED),
		"ECONNRESET":                        reflect.ValueOf(syscall.ECONNRESET),
		"EDEADLK":                           reflect.ValueOf(syscall.EDEADLK),
		"EDESTADDRREQ":                      reflect.ValueOf(syscall.EDESTADDRREQ),
		"EDOM":                              reflect.ValueOf(syscall.EDOM),
		"EDQUOT":                            reflect.ValueOf(syscall.EDQUOT),
		"EEXIST":                            reflect.ValueOf(syscall.EEXIST),
		"EFAULT":                            reflect.ValueOf(syscall.EFAULT),
		"EFBIG":                             reflect.ValueOf(syscall.EFBIG),
		"EFTYPE":                            reflect.ValueOf(syscall.EFTYPE),
		"EHOSTDOWN":                         reflect.ValueOf(syscall.EHOSTDOWN),
		"EHOSTUNREACH":                      reflect.ValueOf(syscall.EHOSTUNREACH),
		"EIDRM":                             reflect.ValueOf(syscall.EIDRM),
		"EILSEQ":                            reflect.ValueOf(syscall.EILSEQ),
		"EINPROGRESS":                       reflect.ValueOf(syscall.EINPROGRESS),
		"EINTR":                             reflect.ValueOf(syscall.EINTR),
		"EINVAL":                            reflect.ValueOf(syscall.EINVAL),
		"EIO":                               reflect.ValueOf(syscall.EIO),
		"EIPSEC":                            reflect.ValueOf(syscall.EIPSEC),
		"EISCONN":                           reflect.ValueOf(syscall.EISCONN),
		"EISDIR":                            reflect.ValueOf(syscall.EISDIR),
		"ELAST":                             reflect.ValueOf(syscall.ELAST),
		"ELOOP":                             reflect.ValueOf(syscall.ELOOP),
		"EMEDIUMTYPE":                       reflect.ValueOf(syscall.EMEDIUMTYPE),
		"EMFILE":                            reflect.ValueOf(syscall.EMFILE),
		"EMLINK":                            reflect.ValueOf(syscall.EMLINK),
		"EMSGSIZE":                          reflect.ValueOf(syscall.EMSGSIZE),
		"EMT_TAGOVF":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EMUL_ENABLED":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EMUL_NATIVE":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ENAMETOOLONG":                      reflect.ValueOf(syscall.ENAMETOOLONG),
		"ENDRUNDISC":                        reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"ENEEDAUTH":                         reflect.ValueOf(syscall.ENEEDAUTH),
		"ENETDOWN":                          reflect.ValueOf(syscall.ENETDOWN),
		"ENETRESET":                         reflect.ValueOf(syscall.ENETRESET),
		"ENETUNREACH":                       reflect.ValueOf(syscall.ENETUNREACH),
		"ENFILE":                            reflect.ValueOf(syscall.ENFILE),
		"ENOATTR":                           reflect.ValueOf(syscall.ENOATTR),
		"ENOBUFS":                           reflect.ValueOf(syscall.ENOBUFS),
		"ENODEV":                            reflect.ValueOf(syscall.ENODEV),
		"ENOENT":                            reflect.ValueOf(syscall.ENOENT),
		"ENOEXEC":                           reflect.ValueOf(syscall.ENOEXEC),
		"ENOLCK":                            reflect.ValueOf(syscall.ENOLCK),
		"ENOMEDIUM":                         reflect.ValueOf(syscall.ENOMEDIUM),
		"ENOMEM":                            reflect.ValueOf(syscall.ENOMEM),
		"ENOMSG":                            reflect.ValueOf(syscall.ENOMSG),
		"ENOPROTOOPT":                       reflect.ValueOf(syscall.ENOPROTOOPT),
		"ENOSPC":                            reflect.ValueOf(syscall.ENOSPC),
		"ENOSYS":                            reflect.ValueOf(syscall.ENOSYS),
		"ENOTBLK":                           reflect.ValueOf(syscall.ENOTBLK),
		"ENOTCONN":                          reflect.ValueOf(syscall.ENOTCONN),
		"ENOTDIR":                           reflect.ValueOf(syscall.ENOTDIR),
		"ENOTEMPTY":                         reflect.ValueOf(syscall.ENOTEMPTY),
		"ENOTSOCK":                          reflect.ValueOf(syscall.ENOTSOCK),
		"ENOTSUP":                           reflect.ValueOf(syscall.ENOTSUP),
		"ENOTTY":                            reflect.ValueOf(syscall.ENOTTY),
		"ENXIO":                             reflect.ValueOf(syscall.ENXIO),
		"EOPNOTSUPP":                        reflect.ValueOf(syscall.EOPNOTSUPP),
		"EOVERFLOW":                         reflect.ValueOf(syscall.EOVERFLOW),
		"EPERM":                             reflect.ValueOf(syscall.EPERM),
		"EPFNOSUPPORT":                      reflect.ValueOf(syscall.EPFNOSUPPORT),
		"EPIPE":                             reflect.ValueOf(syscall.EPIPE),
		"EPROCLIM":                          reflect.ValueOf(syscall.EPROCLIM),
		"EPROCUNAVAIL":                      reflect.ValueOf(syscall.EPROCUNAVAIL),
		"EPROGMISMATCH":                     reflect.ValueOf(syscall.EPROGMISMATCH),
		"EPROGUNAVAIL":                      reflect.ValueOf(syscall.EPROGUNAVAIL),
		"EPROTONOSUPPORT":                   reflect.ValueOf(syscall.EPROTONOSUPPORT),
		"EPROTOTYPE":                        reflect.ValueOf(syscall.EPROTOTYPE),
		"ERANGE":                            reflect.ValueOf(syscall.ERANGE),
		"EREMOTE":                           reflect.ValueOf(syscall.EREMOTE),
		"EROFS":                             reflect.ValueOf(syscall.EROFS),
		"ERPCMISMATCH":                      reflect.ValueOf(syscall.ERPCMISMATCH),
		"ESHUTDOWN":                         reflect.ValueOf(syscall.ESHUTDOWN),
		"ESOCKTNOSUPPORT":                   reflect.ValueOf(syscall.ESOCKTNOSUPPORT),
		"ESPIPE":                            reflect.ValueOf(syscall.ESPIPE),
		"ESRCH":                             reflect.ValueOf(syscall.ESRCH),
		"ESTALE":                            reflect.ValueOf(syscall.ESTALE),
		"ETHERMIN":                          reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"ETHERMTU":                          reflect.ValueOf(constant.MakeFromLiteral("1500", token.INT, 0)),
		"ETHERTYPE_8023":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ETHERTYPE_AARP":                    reflect.ValueOf(constant.MakeFromLiteral("33011", token.INT, 0)),
		"ETHERTYPE_ACCTON":                  reflect.ValueOf(constant.MakeFromLiteral("33680", token.INT, 0)),
		"ETHERTYPE_AEONIC":                  reflect.ValueOf(constant.MakeFromLiteral("32822", token.INT, 0)),
		"ETHERTYPE_ALPHA":                   reflect.ValueOf(constant.MakeFromLiteral("33098", token.INT, 0)),
		"ETHERTYPE_AMBER":                   reflect.ValueOf(constant.MakeFromLiteral("24584", token.INT, 0)),
		"ETHERTYPE_AMOEBA":                  reflect.ValueOf(constant.MakeFromLiteral("33093", token.INT, 0)),
		"ETHERTYPE_AOE":                     reflect.ValueOf(constant.MakeFromLiteral("34978", token.INT, 0)),
		"ETHERTYPE_APOLLO":                  reflect.ValueOf(constant.MakeFromLiteral("33015", token.INT, 0)),
		"ETHERTYPE_APOLLODOMAIN":            reflect.ValueOf(constant.MakeFromLiteral("32793", token.INT, 0)),
		"ETHERTYPE_APPLETALK":               reflect.ValueOf(constant.MakeFromLiteral("32923", token.INT, 0)),
		"ETHERTYPE_APPLITEK":                reflect.ValueOf(constant.MakeFromLiteral("32967", token.INT, 0)),
		"ETHERTYPE_ARGONAUT":                reflect.ValueOf(constant.MakeFromLiteral("32826", token.INT, 0)),
		"ETHERTYPE_ARP":                     reflect.ValueOf(constant.MakeFromLiteral("2054", token.INT, 0)),
		"ETHERTYPE_AT":                      reflect.ValueOf(constant.MakeFromLiteral("32923", token.INT, 0)),
		"ETHERTYPE_ATALK":                   reflect.ValueOf(constant.MakeFromLiteral("32923", token.INT, 0)),
		"ETHERTYPE_ATOMIC":                  reflect.ValueOf(constant.MakeFromLiteral("34527", token.INT, 0)),
		"ETHERTYPE_ATT":                     reflect.ValueOf(constant.MakeFromLiteral("32873", token.INT, 0)),
		"ETHERTYPE_ATTSTANFORD":             reflect.ValueOf(constant.MakeFromLiteral("32776", token.INT, 0)),
		"ETHERTYPE_AUTOPHON":                reflect.ValueOf(constant.MakeFromLiteral("32874", token.INT, 0)),
		"ETHERTYPE_AXIS":                    reflect.ValueOf(constant.MakeFromLiteral("34902", token.INT, 0)),
		"ETHERTYPE_BCLOOP":                  reflect.ValueOf(constant.MakeFromLiteral("36867", token.INT, 0)),
		"ETHERTYPE_BOFL":                    reflect.ValueOf(constant.MakeFromLiteral("33026", token.INT, 0)),
		"ETHERTYPE_CABLETRON":               reflect.ValueOf(constant.MakeFromLiteral("28724", token.INT, 0)),
		"ETHERTYPE_CHAOS":                   reflect.ValueOf(constant.MakeFromLiteral("2052", token.INT, 0)),
		"ETHERTYPE_COMDESIGN":               reflect.ValueOf(constant.MakeFromLiteral("32876", token.INT, 0)),
		"ETHERTYPE_COMPUGRAPHIC":            reflect.ValueOf(constant.MakeFromLiteral("32877", token.INT, 0)),
		"ETHERTYPE_COUNTERPOINT":            reflect.ValueOf(constant.MakeFromLiteral("32866", token.INT, 0)),
		"ETHERTYPE_CRONUS":                  reflect.ValueOf(constant.MakeFromLiteral("32772", token.INT, 0)),
		"ETHERTYPE_CRONUSVLN":               reflect.ValueOf(constant.MakeFromLiteral("32771", token.INT, 0)),
		"ETHERTYPE_DCA":                     reflect.ValueOf(constant.MakeFromLiteral("4660", token.INT, 0)),
		"ETHERTYPE_DDE":                     reflect.ValueOf(constant.MakeFromLiteral("32891", token.INT, 0)),
		"ETHERTYPE_DEBNI":                   reflect.ValueOf(constant.MakeFromLiteral("43690", token.INT, 0)),
		"ETHERTYPE_DECAM":                   reflect.ValueOf(constant.MakeFromLiteral("32840", token.INT, 0)),
		"ETHERTYPE_DECCUST":                 reflect.ValueOf(constant.MakeFromLiteral("24582", token.INT, 0)),
		"ETHERTYPE_DECDIAG":                 reflect.ValueOf(constant.MakeFromLiteral("24581", token.INT, 0)),
		"ETHERTYPE_DECDNS":                  reflect.ValueOf(constant.MakeFromLiteral("32828", token.INT, 0)),
		"ETHERTYPE_DECDTS":                  reflect.ValueOf(constant.MakeFromLiteral("32830", token.INT, 0)),
		"ETHERTYPE_DECEXPER":                reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"ETHERTYPE_DECLAST":                 reflect.ValueOf(constant.MakeFromLiteral("32833", token.INT, 0)),
		"ETHERTYPE_DECLTM":                  reflect.ValueOf(constant.MakeFromLiteral("32831", token.INT, 0)),
		"ETHERTYPE_DECMUMPS":                reflect.ValueOf(constant.MakeFromLiteral("24585", token.INT, 0)),
		"ETHERTYPE_DECNETBIOS":              reflect.ValueOf(constant.MakeFromLiteral("32832", token.INT, 0)),
		"ETHERTYPE_DELTACON":                reflect.ValueOf(constant.MakeFromLiteral("34526", token.INT, 0)),
		"ETHERTYPE_DIDDLE":                  reflect.ValueOf(constant.MakeFromLiteral("17185", token.INT, 0)),
		"ETHERTYPE_DLOG1":                   reflect.ValueOf(constant.MakeFromLiteral("1632", token.INT, 0)),
		"ETHERTYPE_DLOG2":                   reflect.ValueOf(constant.MakeFromLiteral("1633", token.INT, 0)),
		"ETHERTYPE_DN":                      reflect.ValueOf(constant.MakeFromLiteral("24579", token.INT, 0)),
		"ETHERTYPE_DOGFIGHT":                reflect.ValueOf(constant.MakeFromLiteral("6537", token.INT, 0)),
		"ETHERTYPE_DSMD":                    reflect.ValueOf(constant.MakeFromLiteral("32825", token.INT, 0)),
		"ETHERTYPE_ECMA":                    reflect.ValueOf(constant.MakeFromLiteral("2051", token.INT, 0)),
		"ETHERTYPE_ENCRYPT":                 reflect.ValueOf(constant.MakeFromLiteral("32829", token.INT, 0)),
		"ETHERTYPE_ES":                      reflect.ValueOf(constant.MakeFromLiteral("32861", token.INT, 0)),
		"ETHERTYPE_EXCELAN":                 reflect.ValueOf(constant.MakeFromLiteral("32784", token.INT, 0)),
		"ETHERTYPE_EXPERDATA":               reflect.ValueOf(constant.MakeFromLiteral("32841", token.INT, 0)),
		"ETHERTYPE_FLIP":                    reflect.ValueOf(constant.MakeFromLiteral("33094", token.INT, 0)),
		"ETHERTYPE_FLOWCONTROL":             reflect.ValueOf(constant.MakeFromLiteral("34824", token.INT, 0)),
		"ETHERTYPE_FRARP":                   reflect.ValueOf(constant.MakeFromLiteral("2056", token.INT, 0)),
		"ETHERTYPE_GENDYN":                  reflect.ValueOf(constant.MakeFromLiteral("32872", token.INT, 0)),
		"ETHERTYPE_HAYES":                   reflect.ValueOf(constant.MakeFromLiteral("33072", token.INT, 0)),
		"ETHERTYPE_HIPPI_FP":                reflect.ValueOf(constant.MakeFromLiteral("33152", token.INT, 0)),
		"ETHERTYPE_HITACHI":                 reflect.ValueOf(constant.MakeFromLiteral("34848", token.INT, 0)),
		"ETHERTYPE_HP":                      reflect.ValueOf(constant.MakeFromLiteral("32773", token.INT, 0)),
		"ETHERTYPE_IEEEPUP":                 reflect.ValueOf(constant.MakeFromLiteral("2560", token.INT, 0)),
		"ETHERTYPE_IEEEPUPAT":               reflect.ValueOf(constant.MakeFromLiteral("2561", token.INT, 0)),
		"ETHERTYPE_IMLBL":                   reflect.ValueOf(constant.MakeFromLiteral("19522", token.INT, 0)),
		"ETHERTYPE_IMLBLDIAG":               reflect.ValueOf(constant.MakeFromLiteral("16972", token.INT, 0)),
		"ETHERTYPE_IP":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"ETHERTYPE_IPAS":                    reflect.ValueOf(constant.MakeFromLiteral("34668", token.INT, 0)),
		"ETHERTYPE_IPV6":                    reflect.ValueOf(constant.MakeFromLiteral("34525", token.INT, 0)),
		"ETHERTYPE_IPX":                     reflect.ValueOf(constant.MakeFromLiteral("33079", token.INT, 0)),
		"ETHERTYPE_IPXNEW":                  reflect.ValueOf(constant.MakeFromLiteral("32823", token.INT, 0)),
		"ETHERTYPE_KALPANA":                 reflect.ValueOf(constant.MakeFromLiteral("34178", token.INT, 0)),
		"ETHERTYPE_LANBRIDGE":               reflect.ValueOf(constant.MakeFromLiteral("32824", token.INT, 0)),
		"ETHERTYPE_LANPROBE":                reflect.ValueOf(constant.MakeFromLiteral("34952", token.INT, 0)),
		"ETHERTYPE_LAT":                     reflect.ValueOf(constant.MakeFromLiteral("24580", token.INT, 0)),
		"ETHERTYPE_LBACK":                   reflect.ValueOf(constant.MakeFromLiteral("36864", token.INT, 0)),
		"ETHERTYPE_LITTLE":                  reflect.ValueOf(constant.MakeFromLiteral("32864", token.INT, 0)),
		"ETHERTYPE_LLDP":                    reflect.ValueOf(constant.MakeFromLiteral("35020", token.INT, 0)),
		"ETHERTYPE_LOGICRAFT":               reflect.ValueOf(constant.MakeFromLiteral("33096", token.INT, 0)),
		"ETHERTYPE_LOOPBACK":                reflect.ValueOf(constant.MakeFromLiteral("36864", token.INT, 0)),
		"ETHERTYPE_MATRA":                   reflect.ValueOf(constant.MakeFromLiteral("32890", token.INT, 0)),
		"ETHERTYPE_MAX":                     reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"ETHERTYPE_MERIT":                   reflect.ValueOf(constant.MakeFromLiteral("32892", token.INT, 0)),
		"ETHERTYPE_MICP":                    reflect.ValueOf(constant.MakeFromLiteral("34618", token.INT, 0)),
		"ETHERTYPE_MOPDL":                   reflect.ValueOf(constant.MakeFromLiteral("24577", token.INT, 0)),
		"ETHERTYPE_MOPRC":                   reflect.ValueOf(constant.MakeFromLiteral("24578", token.INT, 0)),
		"ETHERTYPE_MOTOROLA":                reflect.ValueOf(constant.MakeFromLiteral("33165", token.INT, 0)),
		"ETHERTYPE_MPLS":                    reflect.ValueOf(constant.MakeFromLiteral("34887", token.INT, 0)),
		"ETHERTYPE_MPLS_MCAST":              reflect.ValueOf(constant.MakeFromLiteral("34888", token.INT, 0)),
		"ETHERTYPE_MUMPS":                   reflect.ValueOf(constant.MakeFromLiteral("33087", token.INT, 0)),
		"ETHERTYPE_NBPCC":                   reflect.ValueOf(constant.MakeFromLiteral("15364", token.INT, 0)),
		"ETHERTYPE_NBPCLAIM":                reflect.ValueOf(constant.MakeFromLiteral("15369", token.INT, 0)),
		"ETHERTYPE_NBPCLREQ":                reflect.ValueOf(constant.MakeFromLiteral("15365", token.INT, 0)),
		"ETHERTYPE_NBPCLRSP":                reflect.ValueOf(constant.MakeFromLiteral("15366", token.INT, 0)),
		"ETHERTYPE_NBPCREQ":                 reflect.ValueOf(constant.MakeFromLiteral("15362", token.INT, 0)),
		"ETHERTYPE_NBPCRSP":                 reflect.ValueOf(constant.MakeFromLiteral("15363", token.INT, 0)),
		"ETHERTYPE_NBPDG":                   reflect.ValueOf(constant.MakeFromLiteral("15367", token.INT, 0)),
		"ETHERTYPE_NBPDGB":                  reflect.ValueOf(constant.MakeFromLiteral("15368", token.INT, 0)),
		"ETHERTYPE_NBPDLTE":                 reflect.ValueOf(constant.MakeFromLiteral("15370", token.INT, 0)),
		"ETHERTYPE_NBPRAR":                  reflect.ValueOf(constant.MakeFromLiteral("15372", token.INT, 0)),
		"ETHERTYPE_NBPRAS":                  reflect.ValueOf(constant.MakeFromLiteral("15371", token.INT, 0)),
		"ETHERTYPE_NBPRST":                  reflect.ValueOf(constant.MakeFromLiteral("15373", token.INT, 0)),
		"ETHERTYPE_NBPSCD":                  reflect.ValueOf(constant.MakeFromLiteral("15361", token.INT, 0)),
		"ETHERTYPE_NBPVCD":                  reflect.ValueOf(constant.MakeFromLiteral("15360", token.INT, 0)),
		"ETHERTYPE_NBS":                     reflect.ValueOf(constant.MakeFromLiteral("2050", token.INT, 0)),
		"ETHERTYPE_NCD":                     reflect.ValueOf(constant.MakeFromLiteral("33097", token.INT, 0)),
		"ETHERTYPE_NESTAR":                  reflect.ValueOf(constant.MakeFromLiteral("32774", token.INT, 0)),
		"ETHERTYPE_NETBEUI":                 reflect.ValueOf(constant.MakeFromLiteral("33169", token.INT, 0)),
		"ETHERTYPE_NOVELL":                  reflect.ValueOf(constant.MakeFromLiteral("33080", token.INT, 0)),
		"ETHERTYPE_NS":                      reflect.ValueOf(constant.MakeFromLiteral("1536", token.INT, 0)),
		"ETHERTYPE_NSAT":                    reflect.ValueOf(constant.MakeFromLiteral("1537", token.INT, 0)),
		"ETHERTYPE_NSCOMPAT":                reflect.ValueOf(constant.MakeFromLiteral("2055", token.INT, 0)),
		"ETHERTYPE_NTRAILER":                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ETHERTYPE_OS9":                     reflect.ValueOf(constant.MakeFromLiteral("28679", token.INT, 0)),
		"ETHERTYPE_OS9NET":                  reflect.ValueOf(constant.MakeFromLiteral("28681", token.INT, 0)),
		"ETHERTYPE_PACER":                   reflect.ValueOf(constant.MakeFromLiteral("32966", token.INT, 0)),
		"ETHERTYPE_PAE":                     reflect.ValueOf(constant.MakeFromLiteral("34958", token.INT, 0)),
		"ETHERTYPE_PCS":                     reflect.ValueOf(constant.MakeFromLiteral("16962", token.INT, 0)),
		"ETHERTYPE_PLANNING":                reflect.ValueOf(constant.MakeFromLiteral("32836", token.INT, 0)),
		"ETHERTYPE_PPP":                     reflect.ValueOf(constant.MakeFromLiteral("34827", token.INT, 0)),
		"ETHERTYPE_PPPOE":                   reflect.ValueOf(constant.MakeFromLiteral("34916", token.INT, 0)),
		"ETHERTYPE_PPPOEDISC":               reflect.ValueOf(constant.MakeFromLiteral("34915", token.INT, 0)),
		"ETHERTYPE_PRIMENTS":                reflect.ValueOf(constant.MakeFromLiteral("28721", token.INT, 0)),
		"ETHERTYPE_PUP":                     reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ETHERTYPE_PUPAT":                   reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ETHERTYPE_QINQ":                    reflect.ValueOf(constant.MakeFromLiteral("34984", token.INT, 0)),
		"ETHERTYPE_RACAL":                   reflect.ValueOf(constant.MakeFromLiteral("28720", token.INT, 0)),
		"ETHERTYPE_RATIONAL":                reflect.ValueOf(constant.MakeFromLiteral("33104", token.INT, 0)),
		"ETHERTYPE_RAWFR":                   reflect.ValueOf(constant.MakeFromLiteral("25945", token.INT, 0)),
		"ETHERTYPE_RCL":                     reflect.ValueOf(constant.MakeFromLiteral("6549", token.INT, 0)),
		"ETHERTYPE_RDP":                     reflect.ValueOf(constant.MakeFromLiteral("34617", token.INT, 0)),
		"ETHERTYPE_RETIX":                   reflect.ValueOf(constant.MakeFromLiteral("33010", token.INT, 0)),
		"ETHERTYPE_REVARP":                  reflect.ValueOf(constant.MakeFromLiteral("32821", token.INT, 0)),
		"ETHERTYPE_SCA":                     reflect.ValueOf(constant.MakeFromLiteral("24583", token.INT, 0)),
		"ETHERTYPE_SECTRA":                  reflect.ValueOf(constant.MakeFromLiteral("34523", token.INT, 0)),
		"ETHERTYPE_SECUREDATA":              reflect.ValueOf(constant.MakeFromLiteral("34669", token.INT, 0)),
		"ETHERTYPE_SGITW":                   reflect.ValueOf(constant.MakeFromLiteral("33150", token.INT, 0)),
		"ETHERTYPE_SG_BOUNCE":               reflect.ValueOf(constant.MakeFromLiteral("32790", token.INT, 0)),
		"ETHERTYPE_SG_DIAG":                 reflect.ValueOf(constant.MakeFromLiteral("32787", token.INT, 0)),
		"ETHERTYPE_SG_NETGAMES":             reflect.ValueOf(constant.MakeFromLiteral("32788", token.INT, 0)),
		"ETHERTYPE_SG_RESV":                 reflect.ValueOf(constant.MakeFromLiteral("32789", token.INT, 0)),
		"ETHERTYPE_SIMNET":                  reflect.ValueOf(constant.MakeFromLiteral("21000", token.INT, 0)),
		"ETHERTYPE_SLOW":                    reflect.ValueOf(constant.MakeFromLiteral("34825", token.INT, 0)),
		"ETHERTYPE_SNA":                     reflect.ValueOf(constant.MakeFromLiteral("32981", token.INT, 0)),
		"ETHERTYPE_SNMP":                    reflect.ValueOf(constant.MakeFromLiteral("33100", token.INT, 0)),
		"ETHERTYPE_SONIX":                   reflect.ValueOf(constant.MakeFromLiteral("64245", token.INT, 0)),
		"ETHERTYPE_SPIDER":                  reflect.ValueOf(constant.MakeFromLiteral("32927", token.INT, 0)),
		"ETHERTYPE_SPRITE":                  reflect.ValueOf(constant.MakeFromLiteral("1280", token.INT, 0)),
		"ETHERTYPE_STP":                     reflect.ValueOf(constant.MakeFromLiteral("33153", token.INT, 0)),
		"ETHERTYPE_TALARIS":                 reflect.ValueOf(constant.MakeFromLiteral("33067", token.INT, 0)),
		"ETHERTYPE_TALARISMC":               reflect.ValueOf(constant.MakeFromLiteral("34091", token.INT, 0)),
		"ETHERTYPE_TCPCOMP":                 reflect.ValueOf(constant.MakeFromLiteral("34667", token.INT, 0)),
		"ETHERTYPE_TCPSM":                   reflect.ValueOf(constant.MakeFromLiteral("36866", token.INT, 0)),
		"ETHERTYPE_TEC":                     reflect.ValueOf(constant.MakeFromLiteral("33103", token.INT, 0)),
		"ETHERTYPE_TIGAN":                   reflect.ValueOf(constant.MakeFromLiteral("32815", token.INT, 0)),
		"ETHERTYPE_TRAIL":                   reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"ETHERTYPE_TRANSETHER":              reflect.ValueOf(constant.MakeFromLiteral("25944", token.INT, 0)),
		"ETHERTYPE_TYMSHARE":                reflect.ValueOf(constant.MakeFromLiteral("32814", token.INT, 0)),
		"ETHERTYPE_UBBST":                   reflect.ValueOf(constant.MakeFromLiteral("28677", token.INT, 0)),
		"ETHERTYPE_UBDEBUG":                 reflect.ValueOf(constant.MakeFromLiteral("2304", token.INT, 0)),
		"ETHERTYPE_UBDIAGLOOP":              reflect.ValueOf(constant.MakeFromLiteral("28674", token.INT, 0)),
		"ETHERTYPE_UBDL":                    reflect.ValueOf(constant.MakeFromLiteral("28672", token.INT, 0)),
		"ETHERTYPE_UBNIU":                   reflect.ValueOf(constant.MakeFromLiteral("28673", token.INT, 0)),
		"ETHERTYPE_UBNMC":                   reflect.ValueOf(constant.MakeFromLiteral("28675", token.INT, 0)),
		"ETHERTYPE_VALID":                   reflect.ValueOf(constant.MakeFromLiteral("5632", token.INT, 0)),
		"ETHERTYPE_VARIAN":                  reflect.ValueOf(constant.MakeFromLiteral("32989", token.INT, 0)),
		"ETHERTYPE_VAXELN":                  reflect.ValueOf(constant.MakeFromLiteral("32827", token.INT, 0)),
		"ETHERTYPE_VEECO":                   reflect.ValueOf(constant.MakeFromLiteral("32871", token.INT, 0)),
		"ETHERTYPE_VEXP":                    reflect.ValueOf(constant.MakeFromLiteral("32859", token.INT, 0)),
		"ETHERTYPE_VGLAB":                   reflect.ValueOf(constant.MakeFromLiteral("33073", token.INT, 0)),
		"ETHERTYPE_VINES":                   reflect.ValueOf(constant.MakeFromLiteral("2989", token.INT, 0)),
		"ETHERTYPE_VINESECHO":               reflect.ValueOf(constant.MakeFromLiteral("2991", token.INT, 0)),
		"ETHERTYPE_VINESLOOP":               reflect.ValueOf(constant.MakeFromLiteral("2990", token.INT, 0)),
		"ETHERTYPE_VITAL":                   reflect.ValueOf(constant.MakeFromLiteral("65280", token.INT, 0)),
		"ETHERTYPE_VLAN":                    reflect.ValueOf(constant.MakeFromLiteral("33024", token.INT, 0)),
		"ETHERTYPE_VLTLMAN":                 reflect.ValueOf(constant.MakeFromLiteral("32896", token.INT, 0)),
		"ETHERTYPE_VPROD":                   reflect.ValueOf(constant.MakeFromLiteral("32860", token.INT, 0)),
		"ETHERTYPE_VURESERVED":              reflect.ValueOf(constant.MakeFromLiteral("33095", token.INT, 0)),
		"ETHERTYPE_WATERLOO":                reflect.ValueOf(constant.MakeFromLiteral("33072", token.INT, 0)),
		"ETHERTYPE_WELLFLEET":               reflect.ValueOf(constant.MakeFromLiteral("33027", token.INT, 0)),
		"ETHERTYPE_X25":                     reflect.ValueOf(constant.MakeFromLiteral("2053", token.INT, 0)),
		"ETHERTYPE_X75":                     reflect.ValueOf(constant.MakeFromLiteral("2049", token.INT, 0)),
		"ETHERTYPE_XNSSM":                   reflect.ValueOf(constant.MakeFromLiteral("36865", token.INT, 0)),
		"ETHERTYPE_XTP":                     reflect.ValueOf(constant.MakeFromLiteral("33149", token.INT, 0)),
		"ETHER_ADDR_LEN":                    reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"ETHER_ALIGN":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ETHER_CRC_LEN":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ETHER_CRC_POLY_BE":                 reflect.ValueOf(constant.MakeFromLiteral("79764918", token.INT, 0)),
		"ETHER_CRC_POLY_LE":                 reflect.ValueOf(constant.MakeFromLiteral("3988292384", token.INT, 0)),
		"ETHER_HDR_LEN":                     reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"ETHER_MAX_DIX_LEN":                 reflect.ValueOf(constant.MakeFromLiteral("1536", token.INT, 0)),
		"ETHER_MAX_LEN":                     reflect.ValueOf(constant.MakeFromLiteral("1518", token.INT, 0)),
		"ETHER_MIN_LEN":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ETHER_TYPE_LEN":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ETHER_VLAN_ENCAP_LEN":              reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ETIMEDOUT":                         reflect.ValueOf(syscall.ETIMEDOUT),
		"ETOOMANYREFS":                      reflect.ValueOf(syscall.ETOOMANYREFS),
		"ETXTBSY":                           reflect.ValueOf(syscall.ETXTBSY),
		"EUSERS":                            reflect.ValueOf(syscall.EUSERS),
		"EVFILT_AIO":                        reflect.ValueOf(constant.MakeFromLiteral("-3", token.INT, 0)),
		"EVFILT_PROC":                       reflect.ValueOf(constant.MakeFromLiteral("-5", token.INT, 0)),
		"EVFILT_READ":                       reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"EVFILT_SIGNAL":                     reflect.ValueOf(constant.MakeFromLiteral("-6", token.INT, 0)),
		"EVFILT_SYSCOUNT":                   reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"EVFILT_TIMER":                      reflect.ValueOf(constant.MakeFromLiteral("-7", token.INT, 0)),
		"EVFILT_VNODE":                      reflect.ValueOf(constant.MakeFromLiteral("-4", token.INT, 0)),
		"EVFILT_WRITE":                      reflect.ValueOf(constant.MakeFromLiteral("-2", token.INT, 0)),
		"EV_ADD":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EV_CLEAR":                          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"EV_DELETE":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"EV_DISABLE":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"EV_ENABLE":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"EV_EOF":                            reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"EV_ERROR":                          reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"EV_FLAG1":                          reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"EV_ONESHOT":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"EV_SYSFLAGS":                       reflect.ValueOf(constant.MakeFromLiteral("61440", token.INT, 0)),
		"EWOULDBLOCK":                       reflect.ValueOf(syscall.EWOULDBLOCK),
		"EXDEV":                             reflect.ValueOf(syscall.EXDEV),
		"EXTA":                              reflect.ValueOf(constant.MakeFromLiteral("19200", token.INT, 0)),
		"EXTB":                              reflect.ValueOf(constant.MakeFromLiteral("38400", token.INT, 0)),
		"EXTPROC":                           reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"Environ":                           reflect.ValueOf(syscall.Environ),
		"FD_CLOEXEC":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FD_SETSIZE":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"FLUSHO":                            reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"F_DUPFD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_DUPFD_CLOEXEC":                   reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"F_GETFD":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_GETFL":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_GETLK":                           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"F_GETOWN":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"F_RDLCK":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_SETFD":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_SETFL":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_SETLK":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_SETLKW":                          reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"F_SETOWN":                          reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"F_UNLCK":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_WRLCK":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"Fchdir":                            reflect.ValueOf(syscall.Fchdir),
		"Fchflags":                          reflect.ValueOf(syscall.Fchflags),
		"Fchmod":                            reflect.ValueOf(syscall.Fchmod),
		"Fchown":                            reflect.ValueOf(syscall.Fchown),
		"FcntlFlock":                        reflect.ValueOf(syscall.FcntlFlock),
		"Flock":                             reflect.ValueOf(syscall.Flock),
		"FlushBpf":                          reflect.ValueOf(syscall.FlushBpf),
		"ForkLock":                          reflect.ValueOf(&syscall.ForkLock).Elem(),
		"Fpathconf":                         reflect.ValueOf(syscall.Fpathconf),
		"Fstat":                             reflect.ValueOf(syscall.Fstat),
		"Fstatfs":                           reflect.ValueOf(syscall.Fstatfs),
		"Fsync":                             reflect.ValueOf(syscall.Fsync),
		"Ftruncate":                         reflect.ValueOf(syscall.Ftruncate),
		"Futimes":                           reflect.ValueOf(syscall.Futimes),
		"Getdirentries":                     reflect.ValueOf(syscall.Getdirentries),
		"Getegid":                           reflect.ValueOf(syscall.Getegid),
		"Getenv":                            reflect.ValueOf(syscall.Getenv),
		"Geteuid":                           reflect.ValueOf(syscall.Geteuid),
		"Getfsstat":                         reflect.ValueOf(syscall.Getfsstat),
		"Getgid":                            reflect.ValueOf(syscall.Getgid),
		"Getgroups":                         reflect.ValueOf(syscall.Getgroups),
		"Getpagesize":                       reflect.ValueOf(syscall.Getpagesize),
		"Getpeername":                       reflect.ValueOf(syscall.Getpeername),
		"Getpgid":                           reflect.ValueOf(syscall.Getpgid),
		"Getpgrp":                           reflect.ValueOf(syscall.Getpgrp),
		"Getpid":                            reflect.ValueOf(syscall.Getpid),
		"Getppid":                           reflect.ValueOf(syscall.Getppid),
		"Getpriority":                       reflect.ValueOf(syscall.Getpriority),
		"Getrlimit":                         reflect.ValueOf(syscall.Getrlimit),
		"Getrusage":                         reflect.ValueOf(syscall.Getrusage),
		"Getsid":                            reflect.ValueOf(syscall.Getsid),
		"Getsockname":                       reflect.ValueOf(syscall.Getsockname),
		"GetsockoptByte":                    reflect.ValueOf(syscall.GetsockoptByte),
		"GetsockoptICMPv6Filter":            reflect.ValueOf(syscall.GetsockoptICMPv6Filter),
		"GetsockoptIPMreq":                  reflect.ValueOf(syscall.GetsockoptIPMreq),
		"GetsockoptIPv6MTUInfo":             reflect.ValueOf(syscall.GetsockoptIPv6MTUInfo),
		"GetsockoptIPv6Mreq":                reflect.ValueOf(syscall.GetsockoptIPv6Mreq),
		"GetsockoptInet4Addr":               reflect.ValueOf(syscall.GetsockoptInet4Addr),
		"GetsockoptInt":                     reflect.ValueOf(syscall.GetsockoptInt),
		"Gettimeofday":                      reflect.ValueOf(syscall.Gettimeofday),
		"Getuid":                            reflect.ValueOf(syscall.Getuid),
		"Getwd":                             reflect.ValueOf(syscall.Getwd),
		"HUPCL":                             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"ICANON":                            reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"ICMP6_FILTER":                      reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"ICRNL":                             reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IEXTEN":                            reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFAN_ARRIVAL":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IFAN_DEPARTURE":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFA_ROUTE":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFF_ALLMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IFF_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFF_CANTCHANGE":                    reflect.ValueOf(constant.MakeFromLiteral("36434", token.INT, 0)),
		"IFF_DEBUG":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFF_LINK0":                         reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IFF_LINK1":                         reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IFF_LINK2":                         reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_LOOPBACK":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFF_MULTICAST":                     reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_NOARP":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFF_NOTRAILERS":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFF_OACTIVE":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFF_POINTOPOINT":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFF_PROMISC":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IFF_RUNNING":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFF_SIMPLEX":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFF_UP":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFNAMSIZ":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFT_1822":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFT_A12MPPSWITCH":                  reflect.ValueOf(constant.MakeFromLiteral("130", token.INT, 0)),
		"IFT_AAL2":                          reflect.ValueOf(constant.MakeFromLiteral("187", token.INT, 0)),
		"IFT_AAL5":                          reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IFT_ADSL":                          reflect.ValueOf(constant.MakeFromLiteral("94", token.INT, 0)),
		"IFT_AFLANE8023":                    reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IFT_AFLANE8025":                    reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IFT_ARAP":                          reflect.ValueOf(constant.MakeFromLiteral("88", token.INT, 0)),
		"IFT_ARCNET":                        reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IFT_ARCNETPLUS":                    reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IFT_ASYNC":                         reflect.ValueOf(constant.MakeFromLiteral("84", token.INT, 0)),
		"IFT_ATM":                           reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IFT_ATMDXI":                        reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"IFT_ATMFUNI":                       reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"IFT_ATMIMA":                        reflect.ValueOf(constant.MakeFromLiteral("107", token.INT, 0)),
		"IFT_ATMLOGICAL":                    reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"IFT_ATMRADIO":                      reflect.ValueOf(constant.MakeFromLiteral("189", token.INT, 0)),
		"IFT_ATMSUBINTERFACE":               reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"IFT_ATMVCIENDPT":                   reflect.ValueOf(constant.MakeFromLiteral("194", token.INT, 0)),
		"IFT_ATMVIRTUAL":                    reflect.ValueOf(constant.MakeFromLiteral("149", token.INT, 0)),
		"IFT_BGPPOLICYACCOUNTING":           reflect.ValueOf(constant.MakeFromLiteral("162", token.INT, 0)),
		"IFT_BLUETOOTH":                     reflect.ValueOf(constant.MakeFromLiteral("248", token.INT, 0)),
		"IFT_BRIDGE":                        reflect.ValueOf(constant.MakeFromLiteral("209", token.INT, 0)),
		"IFT_BSC":                           reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"IFT_CARP":                          reflect.ValueOf(constant.MakeFromLiteral("247", token.INT, 0)),
		"IFT_CCTEMUL":                       reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IFT_CEPT":                          reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IFT_CES":                           reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"IFT_CHANNEL":                       reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"IFT_CNR":                           reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"IFT_COFFEE":                        reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"IFT_COMPOSITELINK":                 reflect.ValueOf(constant.MakeFromLiteral("155", token.INT, 0)),
		"IFT_DCN":                           reflect.ValueOf(constant.MakeFromLiteral("141", token.INT, 0)),
		"IFT_DIGITALPOWERLINE":              reflect.ValueOf(constant.MakeFromLiteral("138", token.INT, 0)),
		"IFT_DIGITALWRAPPEROVERHEADCHANNEL": reflect.ValueOf(constant.MakeFromLiteral("186", token.INT, 0)),
		"IFT_DLSW":                          reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IFT_DOCSCABLEDOWNSTREAM":           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFT_DOCSCABLEMACLAYER":             reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"IFT_DOCSCABLEUPSTREAM":             reflect.ValueOf(constant.MakeFromLiteral("129", token.INT, 0)),
		"IFT_DOCSCABLEUPSTREAMCHANNEL":      reflect.ValueOf(constant.MakeFromLiteral("205", token.INT, 0)),
		"IFT_DS0":                           reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"IFT_DS0BUNDLE":                     reflect.ValueOf(constant.MakeFromLiteral("82", token.INT, 0)),
		"IFT_DS1FDL":                        reflect.ValueOf(constant.MakeFromLiteral("170", token.INT, 0)),
		"IFT_DS3":                           reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IFT_DTM":                           reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"IFT_DUMMY":                         reflect.ValueOf(constant.MakeFromLiteral("241", token.INT, 0)),
		"IFT_DVBASILN":                      reflect.ValueOf(constant.MakeFromLiteral("172", token.INT, 0)),
		"IFT_DVBASIOUT":                     reflect.ValueOf(constant.MakeFromLiteral("173", token.INT, 0)),
		"IFT_DVBRCCDOWNSTREAM":              reflect.ValueOf(constant.MakeFromLiteral("147", token.INT, 0)),
		"IFT_DVBRCCMACLAYER":                reflect.ValueOf(constant.MakeFromLiteral("146", token.INT, 0)),
		"IFT_DVBRCCUPSTREAM":                reflect.ValueOf(constant.MakeFromLiteral("148", token.INT, 0)),
		"IFT_ECONET":                        reflect.ValueOf(constant.MakeFromLiteral("206", token.INT, 0)),
		"IFT_ENC":                           reflect.ValueOf(constant.MakeFromLiteral("244", token.INT, 0)),
		"IFT_EON":                           reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IFT_EPLRS":                         reflect.ValueOf(constant.MakeFromLiteral("87", token.INT, 0)),
		"IFT_ESCON":                         reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"IFT_ETHER":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IFT_FAITH":                         reflect.ValueOf(constant.MakeFromLiteral("243", token.INT, 0)),
		"IFT_FAST":                          reflect.ValueOf(constant.MakeFromLiteral("125", token.INT, 0)),
		"IFT_FASTETHER":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IFT_FASTETHERFX":                   reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"IFT_FDDI":                          reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IFT_FIBRECHANNEL":                  reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"IFT_FRAMERELAYINTERCONNECT":        reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IFT_FRAMERELAYMPI":                 reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"IFT_FRDLCIENDPT":                   reflect.ValueOf(constant.MakeFromLiteral("193", token.INT, 0)),
		"IFT_FRELAY":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFT_FRELAYDCE":                     reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IFT_FRF16MFRBUNDLE":                reflect.ValueOf(constant.MakeFromLiteral("163", token.INT, 0)),
		"IFT_FRFORWARD":                     reflect.ValueOf(constant.MakeFromLiteral("158", token.INT, 0)),
		"IFT_G703AT2MB":                     reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"IFT_G703AT64K":                     reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"IFT_GIF":                           reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"IFT_GIGABITETHERNET":               reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"IFT_GR303IDT":                      reflect.ValueOf(constant.MakeFromLiteral("178", token.INT, 0)),
		"IFT_GR303RDT":                      reflect.ValueOf(constant.MakeFromLiteral("177", token.INT, 0)),
		"IFT_H323GATEKEEPER":                reflect.ValueOf(constant.MakeFromLiteral("164", token.INT, 0)),
		"IFT_H323PROXY":                     reflect.ValueOf(constant.MakeFromLiteral("165", token.INT, 0)),
		"IFT_HDH1822":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IFT_HDLC":                          reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"IFT_HDSL2":                         reflect.ValueOf(constant.MakeFromLiteral("168", token.INT, 0)),
		"IFT_HIPERLAN2":                     reflect.ValueOf(constant.MakeFromLiteral("183", token.INT, 0)),
		"IFT_HIPPI":                         reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IFT_HIPPIINTERFACE":                reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IFT_HOSTPAD":                       reflect.ValueOf(constant.MakeFromLiteral("90", token.INT, 0)),
		"IFT_HSSI":                          reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IFT_HY":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IFT_IBM370PARCHAN":                 reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"IFT_IDSL":                          reflect.ValueOf(constant.MakeFromLiteral("154", token.INT, 0)),
		"IFT_IEEE1394":                      reflect.ValueOf(constant.MakeFromLiteral("144", token.INT, 0)),
		"IFT_IEEE80211":                     reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"IFT_IEEE80212":                     reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IFT_IEEE8023ADLAG":                 reflect.ValueOf(constant.MakeFromLiteral("161", token.INT, 0)),
		"IFT_IFGSN":                         reflect.ValueOf(constant.MakeFromLiteral("145", token.INT, 0)),
		"IFT_IMT":                           reflect.ValueOf(constant.MakeFromLiteral("190", token.INT, 0)),
		"IFT_INFINIBAND":                    reflect.ValueOf(constant.MakeFromLiteral("199", token.INT, 0)),
		"IFT_INTERLEAVE":                    reflect.ValueOf(constant.MakeFromLiteral("124", token.INT, 0)),
		"IFT_IP":                            reflect.ValueOf(constant.MakeFromLiteral("126", token.INT, 0)),
		"IFT_IPFORWARD":                     reflect.ValueOf(constant.MakeFromLiteral("142", token.INT, 0)),
		"IFT_IPOVERATM":                     reflect.ValueOf(constant.MakeFromLiteral("114", token.INT, 0)),
		"IFT_IPOVERCDLC":                    reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"IFT_IPOVERCLAW":                    reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"IFT_IPSWITCH":                      reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"IFT_ISDN":                          reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IFT_ISDNBASIC":                     reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IFT_ISDNPRIMARY":                   reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IFT_ISDNS":                         reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"IFT_ISDNU":                         reflect.ValueOf(constant.MakeFromLiteral("76", token.INT, 0)),
		"IFT_ISO88022LLC":                   reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IFT_ISO88023":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IFT_ISO88024":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFT_ISO88025":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IFT_ISO88025CRFPINT":               reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"IFT_ISO88025DTR":                   reflect.ValueOf(constant.MakeFromLiteral("86", token.INT, 0)),
		"IFT_ISO88025FIBER":                 reflect.ValueOf(constant.MakeFromLiteral("115", token.INT, 0)),
		"IFT_ISO88026":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IFT_ISUP":                          reflect.ValueOf(constant.MakeFromLiteral("179", token.INT, 0)),
		"IFT_L2VLAN":                        reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"IFT_L3IPVLAN":                      reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"IFT_L3IPXVLAN":                     reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"IFT_LAPB":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFT_LAPD":                          reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"IFT_LAPF":                          reflect.ValueOf(constant.MakeFromLiteral("119", token.INT, 0)),
		"IFT_LINEGROUP":                     reflect.ValueOf(constant.MakeFromLiteral("210", token.INT, 0)),
		"IFT_LOCALTALK":                     reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IFT_LOOP":                          reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IFT_MEDIAMAILOVERIP":               reflect.ValueOf(constant.MakeFromLiteral("139", token.INT, 0)),
		"IFT_MFSIGLINK":                     reflect.ValueOf(constant.MakeFromLiteral("167", token.INT, 0)),
		"IFT_MIOX25":                        reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IFT_MODEM":                         reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IFT_MPC":                           reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"IFT_MPLS":                          reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"IFT_MPLSTUNNEL":                    reflect.ValueOf(constant.MakeFromLiteral("150", token.INT, 0)),
		"IFT_MSDSL":                         reflect.ValueOf(constant.MakeFromLiteral("143", token.INT, 0)),
		"IFT_MVL":                           reflect.ValueOf(constant.MakeFromLiteral("191", token.INT, 0)),
		"IFT_MYRINET":                       reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"IFT_NFAS":                          reflect.ValueOf(constant.MakeFromLiteral("175", token.INT, 0)),
		"IFT_NSIP":                          reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IFT_OPTICALCHANNEL":                reflect.ValueOf(constant.MakeFromLiteral("195", token.INT, 0)),
		"IFT_OPTICALTRANSPORT":              reflect.ValueOf(constant.MakeFromLiteral("196", token.INT, 0)),
		"IFT_OTHER":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFT_P10":                           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IFT_P80":                           reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IFT_PARA":                          reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IFT_PFLOG":                         reflect.ValueOf(constant.MakeFromLiteral("245", token.INT, 0)),
		"IFT_PFLOW":                         reflect.ValueOf(constant.MakeFromLiteral("249", token.INT, 0)),
		"IFT_PFSYNC":                        reflect.ValueOf(constant.MakeFromLiteral("246", token.INT, 0)),
		"IFT_PLC":                           reflect.ValueOf(constant.MakeFromLiteral("174", token.INT, 0)),
		"IFT_PON155":                        reflect.ValueOf(constant.MakeFromLiteral("207", token.INT, 0)),
		"IFT_PON622":                        reflect.ValueOf(constant.MakeFromLiteral("208", token.INT, 0)),
		"IFT_POS":                           reflect.ValueOf(constant.MakeFromLiteral("171", token.INT, 0)),
		"IFT_PPP":                           reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IFT_PPPMULTILINKBUNDLE":            reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"IFT_PROPATM":                       reflect.ValueOf(constant.MakeFromLiteral("197", token.INT, 0)),
		"IFT_PROPBWAP2MP":                   reflect.ValueOf(constant.MakeFromLiteral("184", token.INT, 0)),
		"IFT_PROPCNLS":                      reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"IFT_PROPDOCSWIRELESSDOWNSTREAM":    reflect.ValueOf(constant.MakeFromLiteral("181", token.INT, 0)),
		"IFT_PROPDOCSWIRELESSMACLAYER":      reflect.ValueOf(constant.MakeFromLiteral("180", token.INT, 0)),
		"IFT_PROPDOCSWIRELESSUPSTREAM":      reflect.ValueOf(constant.MakeFromLiteral("182", token.INT, 0)),
		"IFT_PROPMUX":                       reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IFT_PROPVIRTUAL":                   reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IFT_PROPWIRELESSP2P":               reflect.ValueOf(constant.MakeFromLiteral("157", token.INT, 0)),
		"IFT_PTPSERIAL":                     reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IFT_PVC":                           reflect.ValueOf(constant.MakeFromLiteral("242", token.INT, 0)),
		"IFT_Q2931":                         reflect.ValueOf(constant.MakeFromLiteral("201", token.INT, 0)),
		"IFT_QLLC":                          reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"IFT_RADIOMAC":                      reflect.ValueOf(constant.MakeFromLiteral("188", token.INT, 0)),
		"IFT_RADSL":                         reflect.ValueOf(constant.MakeFromLiteral("95", token.INT, 0)),
		"IFT_REACHDSL":                      reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"IFT_RFC1483":                       reflect.ValueOf(constant.MakeFromLiteral("159", token.INT, 0)),
		"IFT_RS232":                         reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IFT_RSRB":                          reflect.ValueOf(constant.MakeFromLiteral("79", token.INT, 0)),
		"IFT_SDLC":                          reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IFT_SDSL":                          reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"IFT_SHDSL":                         reflect.ValueOf(constant.MakeFromLiteral("169", token.INT, 0)),
		"IFT_SIP":                           reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IFT_SIPSIG":                        reflect.ValueOf(constant.MakeFromLiteral("204", token.INT, 0)),
		"IFT_SIPTG":                         reflect.ValueOf(constant.MakeFromLiteral("203", token.INT, 0)),
		"IFT_SLIP":                          reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IFT_SMDSDXI":                       reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IFT_SMDSICIP":                      reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IFT_SONET":                         reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IFT_SONETOVERHEADCHANNEL":          reflect.ValueOf(constant.MakeFromLiteral("185", token.INT, 0)),
		"IFT_SONETPATH":                     reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IFT_SONETVT":                       reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IFT_SRP":                           reflect.ValueOf(constant.MakeFromLiteral("151", token.INT, 0)),
		"IFT_SS7SIGLINK":                    reflect.ValueOf(constant.MakeFromLiteral("156", token.INT, 0)),
		"IFT_STACKTOSTACK":                  reflect.ValueOf(constant.MakeFromLiteral("111", token.INT, 0)),
		"IFT_STARLAN":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IFT_T1":                            reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IFT_TDLC":                          reflect.ValueOf(constant.MakeFromLiteral("116", token.INT, 0)),
		"IFT_TELINK":                        reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"IFT_TERMPAD":                       reflect.ValueOf(constant.MakeFromLiteral("91", token.INT, 0)),
		"IFT_TR008":                         reflect.ValueOf(constant.MakeFromLiteral("176", token.INT, 0)),
		"IFT_TRANSPHDLC":                    reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"IFT_TUNNEL":                        reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"IFT_ULTRA":                         reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IFT_USB":                           reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"IFT_V11":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFT_V35":                           reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"IFT_V36":                           reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"IFT_V37":                           reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"IFT_VDSL":                          reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"IFT_VIRTUALIPADDRESS":              reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"IFT_VIRTUALTG":                     reflect.ValueOf(constant.MakeFromLiteral("202", token.INT, 0)),
		"IFT_VOICEDID":                      reflect.ValueOf(constant.MakeFromLiteral("213", token.INT, 0)),
		"IFT_VOICEEM":                       reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"IFT_VOICEEMFGD":                    reflect.ValueOf(constant.MakeFromLiteral("211", token.INT, 0)),
		"IFT_VOICEENCAP":                    reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"IFT_VOICEFGDEANA":                  reflect.ValueOf(constant.MakeFromLiteral("212", token.INT, 0)),
		"IFT_VOICEFXO":                      reflect.ValueOf(constant.MakeFromLiteral("101", token.INT, 0)),
		"IFT_VOICEFXS":                      reflect.ValueOf(constant.MakeFromLiteral("102", token.INT, 0)),
		"IFT_VOICEOVERATM":                  reflect.ValueOf(constant.MakeFromLiteral("152", token.INT, 0)),
		"IFT_VOICEOVERCABLE":                reflect.ValueOf(constant.MakeFromLiteral("198", token.INT, 0)),
		"IFT_VOICEOVERFRAMERELAY":           reflect.ValueOf(constant.MakeFromLiteral("153", token.INT, 0)),
		"IFT_VOICEOVERIP":                   reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"IFT_X213":                          reflect.ValueOf(constant.MakeFromLiteral("93", token.INT, 0)),
		"IFT_X25":                           reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IFT_X25DDN":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFT_X25HUNTGROUP":                  reflect.ValueOf(constant.MakeFromLiteral("122", token.INT, 0)),
		"IFT_X25MLP":                        reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"IFT_X25PLE":                        reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IFT_XETHER":                        reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IGNBRK":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IGNCR":                             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IGNPAR":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IMAXBEL":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"INLCR":                             reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"INPCK":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSA_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("16777215", token.INT, 0)),
		"IN_CLASSA_MAX":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IN_CLASSA_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4278190080", token.INT, 0)),
		"IN_CLASSA_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IN_CLASSB_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IN_CLASSB_MAX":                     reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IN_CLASSB_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"IN_CLASSB_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSC_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IN_CLASSC_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4294967040", token.INT, 0)),
		"IN_CLASSC_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IN_CLASSD_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("268435455", token.INT, 0)),
		"IN_CLASSD_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"IN_CLASSD_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IN_LOOPBACKNET":                    reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"IN_RFC3021_HOST":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IN_RFC3021_NET":                    reflect.ValueOf(constant.MakeFromLiteral("4294967294", token.INT, 0)),
		"IN_RFC3021_NSHIFT":                 reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IPPROTO_AH":                        reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPPROTO_CARP":                      reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"IPPROTO_DIVERT":                    reflect.ValueOf(constant.MakeFromLiteral("258", token.INT, 0)),
		"IPPROTO_DIVERT_INIT":               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPPROTO_DIVERT_RESP":               reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPPROTO_DONE":                      reflect.ValueOf(constant.MakeFromLiteral("257", token.INT, 0)),
		"IPPROTO_DSTOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IPPROTO_EGP":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPPROTO_ENCAP":                     reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"IPPROTO_EON":                       reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"IPPROTO_ESP":                       reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPPROTO_ETHERIP":                   reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"IPPROTO_FRAGMENT":                  reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPPROTO_GGP":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPPROTO_GRE":                       reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IPPROTO_HOPOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_ICMP":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPPROTO_ICMPV6":                    reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IPPROTO_IDP":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPPROTO_IGMP":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPPROTO_IP":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_IPCOMP":                    reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"IPPROTO_IPIP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_IPV4":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_IPV6":                      reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPPROTO_MAX":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IPPROTO_MAXID":                     reflect.ValueOf(constant.MakeFromLiteral("259", token.INT, 0)),
		"IPPROTO_MOBILE":                    reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IPPROTO_MPLS":                      reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"IPPROTO_NONE":                      reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPPROTO_PFSYNC":                    reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"IPPROTO_PIM":                       reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"IPPROTO_PUP":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPPROTO_RAW":                       reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IPPROTO_ROUTING":                   reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPPROTO_RSVP":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPPROTO_TCP":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPPROTO_TP":                        reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPPROTO_UDP":                       reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPV6_AUTH_LEVEL":                   reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IPV6_AUTOFLOWLABEL":                reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPV6_CHECKSUM":                     reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IPV6_DEFAULT_MULTICAST_HOPS":       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_DEFAULT_MULTICAST_LOOP":       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_DEFHLIM":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IPV6_DONTFRAG":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IPV6_DSTOPTS":                      reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPV6_ESP_NETWORK_LEVEL":            reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IPV6_ESP_TRANS_LEVEL":              reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IPV6_FAITH":                        reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPV6_FLOWINFO_MASK":                reflect.ValueOf(constant.MakeFromLiteral("4294967055", token.INT, 0)),
		"IPV6_FLOWLABEL_MASK":               reflect.ValueOf(constant.MakeFromLiteral("4294905600", token.INT, 0)),
		"IPV6_FRAGTTL":                      reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"IPV6_HLIMDEC":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_HOPLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IPV6_HOPOPTS":                      reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IPV6_IPCOMP_LEVEL":                 reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IPV6_JOIN_GROUP":                   reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPV6_LEAVE_GROUP":                  reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IPV6_MAXHLIM":                      reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IPV6_MAXPACKET":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IPV6_MMTU":                         reflect.ValueOf(constant.MakeFromLiteral("1280", token.INT, 0)),
		"IPV6_MULTICAST_HOPS":               reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPV6_MULTICAST_IF":                 reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPV6_MULTICAST_LOOP":               reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IPV6_NEXTHOP":                      reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IPV6_OPTIONS":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_PATHMTU":                      reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPV6_PIPEX":                        reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IPV6_PKTINFO":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPV6_PORTRANGE":                    reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IPV6_PORTRANGE_DEFAULT":            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_PORTRANGE_HIGH":               reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_PORTRANGE_LOW":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPV6_RECVDSTOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IPV6_RECVDSTPORT":                  reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IPV6_RECVHOPLIMIT":                 reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IPV6_RECVHOPOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IPV6_RECVPATHMTU":                  reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPV6_RECVPKTINFO":                  reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IPV6_RECVRTHDR":                    reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IPV6_RECVTCLASS":                   reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IPV6_RTABLE":                       reflect.ValueOf(constant.MakeFromLiteral("4129", token.INT, 0)),
		"IPV6_RTHDR":                        reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPV6_RTHDRDSTOPTS":                 reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IPV6_RTHDR_LOOSE":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_RTHDR_STRICT":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_RTHDR_TYPE_0":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_SOCKOPT_RESERVED1":            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPV6_TCLASS":                       reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IPV6_UNICAST_HOPS":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_USE_MIN_MTU":                  reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IPV6_V6ONLY":                       reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IPV6_VERSION":                      reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"IPV6_VERSION_MASK":                 reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"IP_ADD_MEMBERSHIP":                 reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IP_AUTH_LEVEL":                     reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_LOOP":         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_TTL":          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DF":                             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IP_DIVERTFL":                       reflect.ValueOf(constant.MakeFromLiteral("4130", token.INT, 0)),
		"IP_DROP_MEMBERSHIP":                reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IP_ESP_NETWORK_LEVEL":              reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IP_ESP_TRANS_LEVEL":                reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IP_HDRINCL":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_IPCOMP_LEVEL":                   reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IP_IPSECFLOWINFO":                  reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IP_IPSEC_LOCAL_AUTH":               reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IP_IPSEC_LOCAL_CRED":               reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IP_IPSEC_LOCAL_ID":                 reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IP_IPSEC_REMOTE_AUTH":              reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IP_IPSEC_REMOTE_CRED":              reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IP_IPSEC_REMOTE_ID":                reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IP_MAXPACKET":                      reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IP_MAX_MEMBERSHIPS":                reflect.ValueOf(constant.MakeFromLiteral("4095", token.INT, 0)),
		"IP_MF":                             reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IP_MINTTL":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IP_MIN_MEMBERSHIPS":                reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IP_MSS":                            reflect.ValueOf(constant.MakeFromLiteral("576", token.INT, 0)),
		"IP_MULTICAST_IF":                   reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IP_MULTICAST_LOOP":                 reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IP_MULTICAST_TTL":                  reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_OFFMASK":                        reflect.ValueOf(constant.MakeFromLiteral("8191", token.INT, 0)),
		"IP_OPTIONS":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_PIPEX":                          reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IP_PORTRANGE":                      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IP_PORTRANGE_DEFAULT":              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IP_PORTRANGE_HIGH":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_PORTRANGE_LOW":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_RECVDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IP_RECVDSTPORT":                    reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IP_RECVIF":                         reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IP_RECVOPTS":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IP_RECVRETOPTS":                    reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IP_RECVRTABLE":                     reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IP_RECVTTL":                        reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IP_RETOPTS":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IP_RF":                             reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IP_RTABLE":                         reflect.ValueOf(constant.MakeFromLiteral("4129", token.INT, 0)),
		"IP_TOS":                            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IP_TTL":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ISIG":                              reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"ISTRIP":                            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IXANY":                             reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IXOFF":                             reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IXON":                              reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ImplementsGetwd":                   reflect.ValueOf(syscall.ImplementsGetwd),
		"Issetugid":                         reflect.ValueOf(syscall.Issetugid),
		"Kevent":                            reflect.ValueOf(syscall.Kevent),
		"Kqueue":                            reflect.ValueOf(syscall.Kqueue),
		"LCNT_OVERLOAD_FLUSH":               reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"LOCK_EX":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"LOCK_NB":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"LOCK_SH":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"LOCK_UN":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"Lchown":                            reflect.ValueOf(syscall.Lchown),
		"Link":                              reflect.ValueOf(syscall.Link),
		"Listen":                            reflect.ValueOf(syscall.Listen),
		"Lstat":                             reflect.ValueOf(syscall.Lstat),
		"MADV_DONTNEED":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MADV_FREE":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"MADV_NORMAL":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MADV_RANDOM":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MADV_SEQUENTIAL":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MADV_SPACEAVAIL":                   reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"MADV_WILLNEED":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"MAP_ANON":                          reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"MAP_ANONYMOUS":                     reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"MAP_COPY":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_FILE":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_FIXED":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MAP_FLAGMASK":                      reflect.ValueOf(constant.MakeFromLiteral("16375", token.INT, 0)),
		"MAP_HASSEMAPHORE":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_INHERIT":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_INHERIT_COPY":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MAP_INHERIT_NONE":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_INHERIT_SHARE":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_INHERIT_ZERO":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"MAP_NOEXTEND":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_NORESERVE":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_PRIVATE":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_RENAME":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_SHARED":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MAP_TRYFIXED":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MCL_CURRENT":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MCL_FUTURE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_BCAST":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MSG_CMSG_CLOEXEC":                  reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"MSG_CTRUNC":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MSG_DONTROUTE":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MSG_DONTWAIT":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MSG_EOR":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MSG_MCAST":                         reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"MSG_NOSIGNAL":                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"MSG_OOB":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MSG_PEEK":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_TRUNC":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MSG_WAITALL":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MS_ASYNC":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MS_INVALIDATE":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MS_SYNC":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Mkdir":                             reflect.ValueOf(syscall.Mkdir),
		"Mkfifo":                            reflect.ValueOf(syscall.Mkfifo),
		"Mknod":                             reflect.ValueOf(syscall.Mknod),
		"Mmap":                              reflect.ValueOf(syscall.Mmap),
		"Munmap":                            reflect.ValueOf(syscall.Munmap),
		"NAME_MAX":                          reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"NET_RT_DUMP":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NET_RT_FLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NET_RT_IFLIST":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"NET_RT_MAXID":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"NET_RT_STATS":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NET_RT_TABLE":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"NOFLSH":                            reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"NOTE_ATTRIB":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"NOTE_CHILD":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NOTE_DELETE":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NOTE_EOF":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NOTE_EXEC":                         reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"NOTE_EXIT":                         reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"NOTE_EXTEND":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NOTE_FORK":                         reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"NOTE_LINK":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"NOTE_LOWAT":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NOTE_PCTRLMASK":                    reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"NOTE_PDATAMASK":                    reflect.ValueOf(constant.MakeFromLiteral("1048575", token.INT, 0)),
		"NOTE_RENAME":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"NOTE_REVOKE":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"NOTE_TRACK":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NOTE_TRACKERR":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NOTE_TRUNCATE":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"NOTE_WRITE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Nanosleep":                         reflect.ValueOf(syscall.Nanosleep),
		"NsecToTimespec":                    reflect.ValueOf(syscall.NsecToTimespec),
		"NsecToTimeval":                     reflect.ValueOf(syscall.NsecToTimeval),
		"OCRNL":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ONLCR":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ONLRET":                            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"ONOCR":                             reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ONOEOT":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"OPOST":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"O_ACCMODE":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"O_APPEND":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"O_ASYNC":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_CLOEXEC":                         reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"O_CREAT":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"O_DIRECTORY":                       reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"O_DSYNC":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_EXCL":                            reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"O_EXLOCK":                          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"O_FSYNC":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_NDELAY":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"O_NOCTTY":                          reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"O_NOFOLLOW":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"O_NONBLOCK":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"O_RDONLY":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_RDWR":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"O_RSYNC":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_SHLOCK":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"O_SYNC":                            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_TRUNC":                           reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"O_WRONLY":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Open":                              reflect.ValueOf(syscall.Open),
		"PARENB":                            reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"PARMRK":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PARODD":                            reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"PENDIN":                            reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"PF_FLUSH":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PRIO_PGRP":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PRIO_PROCESS":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PRIO_USER":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PROT_EXEC":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PROT_NONE":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PROT_READ":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PROT_WRITE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_CONT":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PTRACE_KILL":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PTRACE_TRACEME":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ParseDirent":                       reflect.ValueOf(syscall.ParseDirent),
		"ParseRoutingMessage":               reflect.ValueOf(syscall.ParseRoutingMessage),
		"ParseRoutingSockaddr":              reflect.ValueOf(syscall.ParseRoutingSockaddr),
		"ParseSocketControlMessage":         reflect.ValueOf(syscall.ParseSocketControlMessage),
		"ParseUnixRights":                   reflect.ValueOf(syscall.ParseUnixRights),
		"Pathconf":                          reflect.ValueOf(syscall.Pathconf),
		"Pipe":                              reflect.ValueOf(syscall.Pipe),
		"Pipe2":                             reflect.ValueOf(syscall.Pipe2),
		"Pread":                             reflect.ValueOf(syscall.Pread),
		"Pwrite":                            reflect.ValueOf(syscall.Pwrite),
		"RLIMIT_CORE":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RLIMIT_CPU":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RLIMIT_DATA":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RLIMIT_FSIZE":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RLIMIT_NOFILE":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RLIMIT_STACK":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RLIM_INFINITY":                     reflect.ValueOf(constant.MakeFromLiteral("9223372036854775807", token.INT, 0)),
		"RTAX_AUTHOR":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTAX_BRD":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTAX_DST":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTAX_GATEWAY":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTAX_GENMASK":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTAX_IFA":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTAX_IFP":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTAX_LABEL":                        reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTAX_MAX":                          reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTAX_NETMASK":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTAX_SRC":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTAX_SRCMASK":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTA_AUTHOR":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTA_BRD":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTA_DST":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTA_GATEWAY":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTA_GENMASK":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTA_IFA":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTA_IFP":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTA_LABEL":                         reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTA_NETMASK":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTA_SRC":                           reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTA_SRCMASK":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RTF_ANNOUNCE":                      reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RTF_BLACKHOLE":                     reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"RTF_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"RTF_CLONED":                        reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"RTF_CLONING":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTF_DONE":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTF_DYNAMIC":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTF_FMASK":                         reflect.ValueOf(constant.MakeFromLiteral("7403528", token.INT, 0)),
		"RTF_GATEWAY":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTF_HOST":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTF_LLINFO":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTF_LOCAL":                         reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"RTF_MASK":                          reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTF_MODIFIED":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTF_MPATH":                         reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"RTF_MPLS":                          reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"RTF_PERMANENT_ARP":                 reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"RTF_PROTO1":                        reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"RTF_PROTO2":                        reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RTF_PROTO3":                        reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"RTF_REJECT":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTF_STATIC":                        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RTF_UP":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTF_USETRAILERS":                   reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"RTF_XRESOLVE":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RTM_ADD":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTM_CHANGE":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTM_DELADDR":                       reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"RTM_DELETE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTM_DESYNC":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTM_GET":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTM_IFANNOUNCE":                    reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTM_IFINFO":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"RTM_LOCK":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTM_LOSING":                        reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTM_MAXSIZE":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RTM_MISS":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTM_NEWADDR":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTM_REDIRECT":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTM_RESOLVE":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTM_RTTUNIT":                       reflect.ValueOf(constant.MakeFromLiteral("1000000", token.INT, 0)),
		"RTM_VERSION":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTV_EXPIRE":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTV_HOPCOUNT":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTV_MTU":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTV_RPIPE":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTV_RTT":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTV_RTTVAR":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTV_SPIPE":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTV_SSTHRESH":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RT_TABLEID_MAX":                    reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"RUSAGE_CHILDREN":                   reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"RUSAGE_SELF":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RUSAGE_THREAD":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Read":                              reflect.ValueOf(syscall.Read),
		"ReadDirent":                        reflect.ValueOf(syscall.ReadDirent),
		"Readlink":                          reflect.ValueOf(syscall.Readlink),
		"Recvfrom":                          reflect.ValueOf(syscall.Recvfrom),
		"Recvmsg":                           reflect.ValueOf(syscall.Recvmsg),
		"Rename":                            reflect.ValueOf(syscall.Rename),
		"Revoke":                            reflect.ValueOf(syscall.Revoke),
		"Rmdir":                             reflect.ValueOf(syscall.Rmdir),
		"RouteRIB":                          reflect.ValueOf(syscall.RouteRIB),
		"SCM_RIGHTS":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SCM_TIMESTAMP":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SHUT_RD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SHUT_RDWR":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SHUT_WR":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SIGABRT":                           reflect.ValueOf(syscall.SIGABRT),
		"SIGALRM":                           reflect.ValueOf(syscall.SIGALRM),
		"SIGBUS":                            reflect.ValueOf(syscall.SIGBUS),
		"SIGCHLD":                           reflect.ValueOf(syscall.SIGCHLD),
		"SIGCONT":                           reflect.ValueOf(syscall.SIGCONT),
		"SIGEMT":                            reflect.ValueOf(syscall.SIGEMT),
		"SIGFPE":                            reflect.ValueOf(syscall.SIGFPE),
		"SIGHUP":                            reflect.ValueOf(syscall.SIGHUP),
		"SIGILL":                            reflect.ValueOf(syscall.SIGILL),
		"SIGINFO":                           reflect.ValueOf(syscall.SIGINFO),
		"SIGINT":                            reflect.ValueOf(syscall.SIGINT),
		"SIGIO":                             reflect.ValueOf(syscall.SIGIO),
		"SIGIOT":                            reflect.ValueOf(syscall.SIGIOT),
		"SIGKILL":                           reflect.ValueOf(syscall.SIGKILL),
		"SIGPIPE":                           reflect.ValueOf(syscall.SIGPIPE),
		"SIGPROF":                           reflect.ValueOf(syscall.SIGPROF),
		"SIGQUIT":                           reflect.ValueOf(syscall.SIGQUIT),
		"SIGSEGV":                           reflect.ValueOf(syscall.SIGSEGV),
		"SIGSTOP":                           reflect.ValueOf(syscall.SIGSTOP),
		"SIGSYS":                            reflect.ValueOf(syscall.SIGSYS),
		"SIGTERM":                           reflect.ValueOf(syscall.SIGTERM),
		"SIGTHR":                            reflect.ValueOf(syscall.SIGTHR),
		"SIGTRAP":                           reflect.ValueOf(syscall.SIGTRAP),
		"SIGTSTP":                           reflect.ValueOf(syscall.SIGTSTP),
		"SIGTTIN":                           reflect.ValueOf(syscall.SIGTTIN),
		"SIGTTOU":                           reflect.ValueOf(syscall.SIGTTOU),
		"SIGURG":                            reflect.ValueOf(syscall.SIGURG),
		"SIGUSR1":                           reflect.ValueOf(syscall.SIGUSR1),
		"SIGUSR2":                           reflect.ValueOf(syscall.SIGUSR2),
		"SIGVTALRM":                         reflect.ValueOf(syscall.SIGVTALRM),
		"SIGWINCH":                          reflect.ValueOf(syscall.SIGWINCH),
		"SIGXCPU":                           reflect.ValueOf(syscall.SIGXCPU),
		"SIGXFSZ":                           reflect.ValueOf(syscall.SIGXFSZ),
		"SIOCADDMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("2149607729", token.INT, 0)),
		"SIOCAIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("2151704858", token.INT, 0)),
		"SIOCAIFGROUP":                      reflect.ValueOf(constant.MakeFromLiteral("2149869959", token.INT, 0)),
		"SIOCALIFADDR":                      reflect.ValueOf(constant.MakeFromLiteral("2182637852", token.INT, 0)),
		"SIOCATMARK":                        reflect.ValueOf(constant.MakeFromLiteral("1074033415", token.INT, 0)),
		"SIOCBRDGADD":                       reflect.ValueOf(constant.MakeFromLiteral("2153015612", token.INT, 0)),
		"SIOCBRDGADDS":                      reflect.ValueOf(constant.MakeFromLiteral("2153015617", token.INT, 0)),
		"SIOCBRDGARL":                       reflect.ValueOf(constant.MakeFromLiteral("2154719565", token.INT, 0)),
		"SIOCBRDGDADDR":                     reflect.ValueOf(constant.MakeFromLiteral("2166909255", token.INT, 0)),
		"SIOCBRDGDEL":                       reflect.ValueOf(constant.MakeFromLiteral("2153015613", token.INT, 0)),
		"SIOCBRDGDELS":                      reflect.ValueOf(constant.MakeFromLiteral("2153015618", token.INT, 0)),
		"SIOCBRDGFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("2153015624", token.INT, 0)),
		"SIOCBRDGFRL":                       reflect.ValueOf(constant.MakeFromLiteral("2154719566", token.INT, 0)),
		"SIOCBRDGGCACHE":                    reflect.ValueOf(constant.MakeFromLiteral("3222563137", token.INT, 0)),
		"SIOCBRDGGFD":                       reflect.ValueOf(constant.MakeFromLiteral("3222563154", token.INT, 0)),
		"SIOCBRDGGHT":                       reflect.ValueOf(constant.MakeFromLiteral("3222563153", token.INT, 0)),
		"SIOCBRDGGIFFLGS":                   reflect.ValueOf(constant.MakeFromLiteral("3226757438", token.INT, 0)),
		"SIOCBRDGGMA":                       reflect.ValueOf(constant.MakeFromLiteral("3222563155", token.INT, 0)),
		"SIOCBRDGGPARAM":                    reflect.ValueOf(constant.MakeFromLiteral("3225184600", token.INT, 0)),
		"SIOCBRDGGPRI":                      reflect.ValueOf(constant.MakeFromLiteral("3222563152", token.INT, 0)),
		"SIOCBRDGGRL":                       reflect.ValueOf(constant.MakeFromLiteral("3223873871", token.INT, 0)),
		"SIOCBRDGGSIFS":                     reflect.ValueOf(constant.MakeFromLiteral("3226757436", token.INT, 0)),
		"SIOCBRDGGTO":                       reflect.ValueOf(constant.MakeFromLiteral("3222563142", token.INT, 0)),
		"SIOCBRDGIFS":                       reflect.ValueOf(constant.MakeFromLiteral("3226757442", token.INT, 0)),
		"SIOCBRDGRTS":                       reflect.ValueOf(constant.MakeFromLiteral("3222825283", token.INT, 0)),
		"SIOCBRDGSADDR":                     reflect.ValueOf(constant.MakeFromLiteral("3240651076", token.INT, 0)),
		"SIOCBRDGSCACHE":                    reflect.ValueOf(constant.MakeFromLiteral("2148821312", token.INT, 0)),
		"SIOCBRDGSFD":                       reflect.ValueOf(constant.MakeFromLiteral("2148821330", token.INT, 0)),
		"SIOCBRDGSHT":                       reflect.ValueOf(constant.MakeFromLiteral("2148821329", token.INT, 0)),
		"SIOCBRDGSIFCOST":                   reflect.ValueOf(constant.MakeFromLiteral("2153015637", token.INT, 0)),
		"SIOCBRDGSIFFLGS":                   reflect.ValueOf(constant.MakeFromLiteral("2153015615", token.INT, 0)),
		"SIOCBRDGSIFPRIO":                   reflect.ValueOf(constant.MakeFromLiteral("2153015636", token.INT, 0)),
		"SIOCBRDGSMA":                       reflect.ValueOf(constant.MakeFromLiteral("2148821331", token.INT, 0)),
		"SIOCBRDGSPRI":                      reflect.ValueOf(constant.MakeFromLiteral("2148821328", token.INT, 0)),
		"SIOCBRDGSPROTO":                    reflect.ValueOf(constant.MakeFromLiteral("2148821338", token.INT, 0)),
		"SIOCBRDGSTO":                       reflect.ValueOf(constant.MakeFromLiteral("2148821317", token.INT, 0)),
		"SIOCBRDGSTXHC":                     reflect.ValueOf(constant.MakeFromLiteral("2148821337", token.INT, 0)),
		"SIOCDELMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("2149607730", token.INT, 0)),
		"SIOCDIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("2149607705", token.INT, 0)),
		"SIOCDIFGROUP":                      reflect.ValueOf(constant.MakeFromLiteral("2149869961", token.INT, 0)),
		"SIOCDIFPHYADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2149607753", token.INT, 0)),
		"SIOCDLIFADDR":                      reflect.ValueOf(constant.MakeFromLiteral("2182637854", token.INT, 0)),
		"SIOCGETKALIVE":                     reflect.ValueOf(constant.MakeFromLiteral("3222825380", token.INT, 0)),
		"SIOCGETLABEL":                      reflect.ValueOf(constant.MakeFromLiteral("2149607834", token.INT, 0)),
		"SIOCGETPFLOW":                      reflect.ValueOf(constant.MakeFromLiteral("3223349758", token.INT, 0)),
		"SIOCGETPFSYNC":                     reflect.ValueOf(constant.MakeFromLiteral("3223349752", token.INT, 0)),
		"SIOCGETSGCNT":                      reflect.ValueOf(constant.MakeFromLiteral("3222566196", token.INT, 0)),
		"SIOCGETVIFCNT":                     reflect.ValueOf(constant.MakeFromLiteral("3222566195", token.INT, 0)),
		"SIOCGETVLAN":                       reflect.ValueOf(constant.MakeFromLiteral("3223349648", token.INT, 0)),
		"SIOCGHIWAT":                        reflect.ValueOf(constant.MakeFromLiteral("1074033409", token.INT, 0)),
		"SIOCGIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("3223349537", token.INT, 0)),
		"SIOCGIFASYNCMAP":                   reflect.ValueOf(constant.MakeFromLiteral("3223349628", token.INT, 0)),
		"SIOCGIFBRDADDR":                    reflect.ValueOf(constant.MakeFromLiteral("3223349539", token.INT, 0)),
		"SIOCGIFCONF":                       reflect.ValueOf(constant.MakeFromLiteral("3221776676", token.INT, 0)),
		"SIOCGIFDATA":                       reflect.ValueOf(constant.MakeFromLiteral("3223349531", token.INT, 0)),
		"SIOCGIFDESCR":                      reflect.ValueOf(constant.MakeFromLiteral("3223349633", token.INT, 0)),
		"SIOCGIFDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("3223349538", token.INT, 0)),
		"SIOCGIFFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("3223349521", token.INT, 0)),
		"SIOCGIFGATTR":                      reflect.ValueOf(constant.MakeFromLiteral("3223611787", token.INT, 0)),
		"SIOCGIFGENERIC":                    reflect.ValueOf(constant.MakeFromLiteral("3223349562", token.INT, 0)),
		"SIOCGIFGMEMB":                      reflect.ValueOf(constant.MakeFromLiteral("3223611786", token.INT, 0)),
		"SIOCGIFGROUP":                      reflect.ValueOf(constant.MakeFromLiteral("3223611784", token.INT, 0)),
		"SIOCGIFHARDMTU":                    reflect.ValueOf(constant.MakeFromLiteral("3223349669", token.INT, 0)),
		"SIOCGIFMEDIA":                      reflect.ValueOf(constant.MakeFromLiteral("3223873846", token.INT, 0)),
		"SIOCGIFMETRIC":                     reflect.ValueOf(constant.MakeFromLiteral("3223349527", token.INT, 0)),
		"SIOCGIFMTU":                        reflect.ValueOf(constant.MakeFromLiteral("3223349630", token.INT, 0)),
		"SIOCGIFNETMASK":                    reflect.ValueOf(constant.MakeFromLiteral("3223349541", token.INT, 0)),
		"SIOCGIFPDSTADDR":                   reflect.ValueOf(constant.MakeFromLiteral("3223349576", token.INT, 0)),
		"SIOCGIFPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("3223349660", token.INT, 0)),
		"SIOCGIFPSRCADDR":                   reflect.ValueOf(constant.MakeFromLiteral("3223349575", token.INT, 0)),
		"SIOCGIFRDOMAIN":                    reflect.ValueOf(constant.MakeFromLiteral("3223349664", token.INT, 0)),
		"SIOCGIFRTLABEL":                    reflect.ValueOf(constant.MakeFromLiteral("3223349635", token.INT, 0)),
		"SIOCGIFRXR":                        reflect.ValueOf(constant.MakeFromLiteral("2149607850", token.INT, 0)),
		"SIOCGIFTIMESLOT":                   reflect.ValueOf(constant.MakeFromLiteral("3223349638", token.INT, 0)),
		"SIOCGIFXFLAGS":                     reflect.ValueOf(constant.MakeFromLiteral("3223349662", token.INT, 0)),
		"SIOCGLIFADDR":                      reflect.ValueOf(constant.MakeFromLiteral("3256379677", token.INT, 0)),
		"SIOCGLIFPHYADDR":                   reflect.ValueOf(constant.MakeFromLiteral("3256379723", token.INT, 0)),
		"SIOCGLIFPHYRTABLE":                 reflect.ValueOf(constant.MakeFromLiteral("3223349666", token.INT, 0)),
		"SIOCGLIFPHYTTL":                    reflect.ValueOf(constant.MakeFromLiteral("3223349673", token.INT, 0)),
		"SIOCGLOWAT":                        reflect.ValueOf(constant.MakeFromLiteral("1074033411", token.INT, 0)),
		"SIOCGPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("1074033417", token.INT, 0)),
		"SIOCGSPPPPARAMS":                   reflect.ValueOf(constant.MakeFromLiteral("3223349652", token.INT, 0)),
		"SIOCGVH":                           reflect.ValueOf(constant.MakeFromLiteral("3223349750", token.INT, 0)),
		"SIOCGVNETID":                       reflect.ValueOf(constant.MakeFromLiteral("3223349671", token.INT, 0)),
		"SIOCIFCREATE":                      reflect.ValueOf(constant.MakeFromLiteral("2149607802", token.INT, 0)),
		"SIOCIFDESTROY":                     reflect.ValueOf(constant.MakeFromLiteral("2149607801", token.INT, 0)),
		"SIOCIFGCLONERS":                    reflect.ValueOf(constant.MakeFromLiteral("3222038904", token.INT, 0)),
		"SIOCSETKALIVE":                     reflect.ValueOf(constant.MakeFromLiteral("2149083555", token.INT, 0)),
		"SIOCSETLABEL":                      reflect.ValueOf(constant.MakeFromLiteral("2149607833", token.INT, 0)),
		"SIOCSETPFLOW":                      reflect.ValueOf(constant.MakeFromLiteral("2149607933", token.INT, 0)),
		"SIOCSETPFSYNC":                     reflect.ValueOf(constant.MakeFromLiteral("2149607927", token.INT, 0)),
		"SIOCSETVLAN":                       reflect.ValueOf(constant.MakeFromLiteral("2149607823", token.INT, 0)),
		"SIOCSHIWAT":                        reflect.ValueOf(constant.MakeFromLiteral("2147775232", token.INT, 0)),
		"SIOCSIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("2149607692", token.INT, 0)),
		"SIOCSIFASYNCMAP":                   reflect.ValueOf(constant.MakeFromLiteral("2149607805", token.INT, 0)),
		"SIOCSIFBRDADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2149607699", token.INT, 0)),
		"SIOCSIFDESCR":                      reflect.ValueOf(constant.MakeFromLiteral("2149607808", token.INT, 0)),
		"SIOCSIFDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2149607694", token.INT, 0)),
		"SIOCSIFFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("2149607696", token.INT, 0)),
		"SIOCSIFGATTR":                      reflect.ValueOf(constant.MakeFromLiteral("2149869964", token.INT, 0)),
		"SIOCSIFGENERIC":                    reflect.ValueOf(constant.MakeFromLiteral("2149607737", token.INT, 0)),
		"SIOCSIFLLADDR":                     reflect.ValueOf(constant.MakeFromLiteral("2149607711", token.INT, 0)),
		"SIOCSIFMEDIA":                      reflect.ValueOf(constant.MakeFromLiteral("3223349557", token.INT, 0)),
		"SIOCSIFMETRIC":                     reflect.ValueOf(constant.MakeFromLiteral("2149607704", token.INT, 0)),
		"SIOCSIFMTU":                        reflect.ValueOf(constant.MakeFromLiteral("2149607807", token.INT, 0)),
		"SIOCSIFNETMASK":                    reflect.ValueOf(constant.MakeFromLiteral("2149607702", token.INT, 0)),
		"SIOCSIFPHYADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2151704902", token.INT, 0)),
		"SIOCSIFPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("2149607835", token.INT, 0)),
		"SIOCSIFRDOMAIN":                    reflect.ValueOf(constant.MakeFromLiteral("2149607839", token.INT, 0)),
		"SIOCSIFRTLABEL":                    reflect.ValueOf(constant.MakeFromLiteral("2149607810", token.INT, 0)),
		"SIOCSIFTIMESLOT":                   reflect.ValueOf(constant.MakeFromLiteral("2149607813", token.INT, 0)),
		"SIOCSIFXFLAGS":                     reflect.ValueOf(constant.MakeFromLiteral("2149607837", token.INT, 0)),
		"SIOCSLIFPHYADDR":                   reflect.ValueOf(constant.MakeFromLiteral("2182637898", token.INT, 0)),
		"SIOCSLIFPHYRTABLE":                 reflect.ValueOf(constant.MakeFromLiteral("2149607841", token.INT, 0)),
		"SIOCSLIFPHYTTL":                    reflect.ValueOf(constant.MakeFromLiteral("2149607848", token.INT, 0)),
		"SIOCSLOWAT":                        reflect.ValueOf(constant.MakeFromLiteral("2147775234", token.INT, 0)),
		"SIOCSPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("2147775240", token.INT, 0)),
		"SIOCSSPPPPARAMS":                   reflect.ValueOf(constant.MakeFromLiteral("2149607827", token.INT, 0)),
		"SIOCSVH":                           reflect.ValueOf(constant.MakeFromLiteral("3223349749", token.INT, 0)),
		"SIOCSVNETID":                       reflect.ValueOf(constant.MakeFromLiteral("2149607846", token.INT, 0)),
		"SOCK_CLOEXEC":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"SOCK_DGRAM":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_NONBLOCK":                     reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"SOCK_RAW":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SOCK_RDM":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SOCK_SEQPACKET":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SOCK_STREAM":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOL_SOCKET":                        reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"SOMAXCONN":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_ACCEPTCONN":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SO_BINDANY":                        reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"SO_BROADCAST":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SO_DEBUG":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SO_DONTROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SO_ERROR":                          reflect.ValueOf(constant.MakeFromLiteral("4103", token.INT, 0)),
		"SO_KEEPALIVE":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SO_LINGER":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_NETPROC":                        reflect.ValueOf(constant.MakeFromLiteral("4128", token.INT, 0)),
		"SO_OOBINLINE":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"SO_PEERCRED":                       reflect.ValueOf(constant.MakeFromLiteral("4130", token.INT, 0)),
		"SO_RCVBUF":                         reflect.ValueOf(constant.MakeFromLiteral("4098", token.INT, 0)),
		"SO_RCVLOWAT":                       reflect.ValueOf(constant.MakeFromLiteral("4100", token.INT, 0)),
		"SO_RCVTIMEO":                       reflect.ValueOf(constant.MakeFromLiteral("4102", token.INT, 0)),
		"SO_REUSEADDR":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SO_REUSEPORT":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"SO_RTABLE":                         reflect.ValueOf(constant.MakeFromLiteral("4129", token.INT, 0)),
		"SO_SNDBUF":                         reflect.ValueOf(constant.MakeFromLiteral("4097", token.INT, 0)),
		"SO_SNDLOWAT":                       reflect.ValueOf(constant.MakeFromLiteral("4099", token.INT, 0)),
		"SO_SNDTIMEO":                       reflect.ValueOf(constant.MakeFromLiteral("4101", token.INT, 0)),
		"SO_SPLICE":                         reflect.ValueOf(constant.MakeFromLiteral("4131", token.INT, 0)),
		"SO_TIMESTAMP":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"SO_TYPE":                           reflect.ValueOf(constant.MakeFromLiteral("4104", token.INT, 0)),
		"SO_USELOOPBACK":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SYS_ACCEPT":                        reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"SYS_ACCEPT4":                       reflect.ValueOf(constant.MakeFromLiteral("93", token.INT, 0)),
		"SYS_ACCESS":                        reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"SYS_ACCT":                          reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"SYS_ADJFREQ":                       reflect.ValueOf(constant.MakeFromLiteral("305", token.INT, 0)),
		"SYS_ADJTIME":                       reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"SYS_BIND":                          reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"SYS_CHDIR":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SYS_CHFLAGS":                       reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"SYS_CHFLAGSAT":                     reflect.ValueOf(constant.MakeFromLiteral("107", token.INT, 0)),
		"SYS_CHMOD":                         reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"SYS_CHOWN":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SYS_CHROOT":                        reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"SYS_CLOCK_GETRES":                  reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"SYS_CLOCK_GETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("87", token.INT, 0)),
		"SYS_CLOCK_SETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("88", token.INT, 0)),
		"SYS_CLOSE":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SYS_CLOSEFROM":                     reflect.ValueOf(constant.MakeFromLiteral("287", token.INT, 0)),
		"SYS_CONNECT":                       reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"SYS_DUP":                           reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"SYS_DUP2":                          reflect.ValueOf(constant.MakeFromLiteral("90", token.INT, 0)),
		"SYS_DUP3":                          reflect.ValueOf(constant.MakeFromLiteral("102", token.INT, 0)),
		"SYS_EXECVE":                        reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"SYS_EXIT":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SYS_FACCESSAT":                     reflect.ValueOf(constant.MakeFromLiteral("313", token.INT, 0)),
		"SYS_FCHDIR":                        reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"SYS_FCHFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"SYS_FCHMOD":                        reflect.ValueOf(constant.MakeFromLiteral("124", token.INT, 0)),
		"SYS_FCHMODAT":                      reflect.ValueOf(constant.MakeFromLiteral("314", token.INT, 0)),
		"SYS_FCHOWN":                        reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"SYS_FCHOWNAT":                      reflect.ValueOf(constant.MakeFromLiteral("315", token.INT, 0)),
		"SYS_FCNTL":                         reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"SYS_FHOPEN":                        reflect.ValueOf(constant.MakeFromLiteral("264", token.INT, 0)),
		"SYS_FHSTAT":                        reflect.ValueOf(constant.MakeFromLiteral("294", token.INT, 0)),
		"SYS_FHSTATFS":                      reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"SYS_FLOCK":                         reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"SYS_FORK":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SYS_FPATHCONF":                     reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"SYS_FSTAT":                         reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"SYS_FSTATAT":                       reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"SYS_FSTATFS":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SYS_FSYNC":                         reflect.ValueOf(constant.MakeFromLiteral("95", token.INT, 0)),
		"SYS_FTRUNCATE":                     reflect.ValueOf(constant.MakeFromLiteral("201", token.INT, 0)),
		"SYS_FUTIMENS":                      reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"SYS_FUTIMES":                       reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"SYS_GETDENTS":                      reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"SYS_GETDTABLECOUNT":                reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"SYS_GETEGID":                       reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"SYS_GETENTROPY":                    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"SYS_GETEUID":                       reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"SYS_GETFH":                         reflect.ValueOf(constant.MakeFromLiteral("161", token.INT, 0)),
		"SYS_GETFSSTAT":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"SYS_GETGID":                        reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"SYS_GETGROUPS":                     reflect.ValueOf(constant.MakeFromLiteral("79", token.INT, 0)),
		"SYS_GETITIMER":                     reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"SYS_GETLOGIN":                      reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"SYS_GETPEERNAME":                   reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"SYS_GETPGID":                       reflect.ValueOf(constant.MakeFromLiteral("207", token.INT, 0)),
		"SYS_GETPGRP":                       reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"SYS_GETPID":                        reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SYS_GETPPID":                       reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"SYS_GETPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"SYS_GETRESGID":                     reflect.ValueOf(constant.MakeFromLiteral("283", token.INT, 0)),
		"SYS_GETRESUID":                     reflect.ValueOf(constant.MakeFromLiteral("281", token.INT, 0)),
		"SYS_GETRLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("194", token.INT, 0)),
		"SYS_GETRTABLE":                     reflect.ValueOf(constant.MakeFromLiteral("311", token.INT, 0)),
		"SYS_GETRUSAGE":                     reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"SYS_GETSID":                        reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"SYS_GETSOCKNAME":                   reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SYS_GETSOCKOPT":                    reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"SYS_GETTHRID":                      reflect.ValueOf(constant.MakeFromLiteral("299", token.INT, 0)),
		"SYS_GETTIMEOFDAY":                  reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"SYS_GETUID":                        reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"SYS_IOCTL":                         reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"SYS_ISSETUGID":                     reflect.ValueOf(constant.MakeFromLiteral("253", token.INT, 0)),
		"SYS_KEVENT":                        reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"SYS_KILL":                          reflect.ValueOf(constant.MakeFromLiteral("122", token.INT, 0)),
		"SYS_KQUEUE":                        reflect.ValueOf(constant.MakeFromLiteral("269", token.INT, 0)),
		"SYS_KTRACE":                        reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"SYS_LCHOWN":                        reflect.ValueOf(constant.MakeFromLiteral("254", token.INT, 0)),
		"SYS_LINK":                          reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"SYS_LINKAT":                        reflect.ValueOf(constant.MakeFromLiteral("317", token.INT, 0)),
		"SYS_LISTEN":                        reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"SYS_LSEEK":                         reflect.ValueOf(constant.MakeFromLiteral("199", token.INT, 0)),
		"SYS_LSTAT":                         reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"SYS_MADVISE":                       reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"SYS_MINCORE":                       reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"SYS_MINHERIT":                      reflect.ValueOf(constant.MakeFromLiteral("250", token.INT, 0)),
		"SYS_MKDIR":                         reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"SYS_MKDIRAT":                       reflect.ValueOf(constant.MakeFromLiteral("318", token.INT, 0)),
		"SYS_MKFIFO":                        reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"SYS_MKFIFOAT":                      reflect.ValueOf(constant.MakeFromLiteral("319", token.INT, 0)),
		"SYS_MKNOD":                         reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"SYS_MKNODAT":                       reflect.ValueOf(constant.MakeFromLiteral("320", token.INT, 0)),
		"SYS_MLOCK":                         reflect.ValueOf(constant.MakeFromLiteral("203", token.INT, 0)),
		"SYS_MLOCKALL":                      reflect.ValueOf(constant.MakeFromLiteral("271", token.INT, 0)),
		"SYS_MMAP":                          reflect.ValueOf(constant.MakeFromLiteral("197", token.INT, 0)),
		"SYS_MOUNT":                         reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"SYS_MPROTECT":                      reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"SYS_MQUERY":                        reflect.ValueOf(constant.MakeFromLiteral("286", token.INT, 0)),
		"SYS_MSGCTL":                        reflect.ValueOf(constant.MakeFromLiteral("297", token.INT, 0)),
		"SYS_MSGGET":                        reflect.ValueOf(constant.MakeFromLiteral("225", token.INT, 0)),
		"SYS_MSGRCV":                        reflect.ValueOf(constant.MakeFromLiteral("227", token.INT, 0)),
		"SYS_MSGSND":                        reflect.ValueOf(constant.MakeFromLiteral("226", token.INT, 0)),
		"SYS_MSYNC":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"SYS_MUNLOCK":                       reflect.ValueOf(constant.MakeFromLiteral("204", token.INT, 0)),
		"SYS_MUNLOCKALL":                    reflect.ValueOf(constant.MakeFromLiteral("272", token.INT, 0)),
		"SYS_MUNMAP":                        reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"SYS_NANOSLEEP":                     reflect.ValueOf(constant.MakeFromLiteral("91", token.INT, 0)),
		"SYS_NFSSVC":                        reflect.ValueOf(constant.MakeFromLiteral("155", token.INT, 0)),
		"SYS_OBREAK":                        reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"SYS_OPEN":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SYS_OPENAT":                        reflect.ValueOf(constant.MakeFromLiteral("321", token.INT, 0)),
		"SYS_PATHCONF":                      reflect.ValueOf(constant.MakeFromLiteral("191", token.INT, 0)),
		"SYS_PIPE":                          reflect.ValueOf(constant.MakeFromLiteral("263", token.INT, 0)),
		"SYS_PIPE2":                         reflect.ValueOf(constant.MakeFromLiteral("101", token.INT, 0)),
		"SYS_POLL":                          reflect.ValueOf(constant.MakeFromLiteral("252", token.INT, 0)),
		"SYS_PPOLL":                         reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"SYS_PREAD":                         reflect.ValueOf(constant.MakeFromLiteral("173", token.INT, 0)),
		"SYS_PREADV":                        reflect.ValueOf(constant.MakeFromLiteral("267", token.INT, 0)),
		"SYS_PROFIL":                        reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"SYS_PSELECT":                       reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"SYS_PTRACE":                        reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"SYS_PWRITE":                        reflect.ValueOf(constant.MakeFromLiteral("174", token.INT, 0)),
		"SYS_PWRITEV":                       reflect.ValueOf(constant.MakeFromLiteral("268", token.INT, 0)),
		"SYS_QUOTACTL":                      reflect.ValueOf(constant.MakeFromLiteral("148", token.INT, 0)),
		"SYS_READ":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SYS_READLINK":                      reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"SYS_READLINKAT":                    reflect.ValueOf(constant.MakeFromLiteral("322", token.INT, 0)),
		"SYS_READV":                         reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"SYS_REBOOT":                        reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"SYS_RECVFROM":                      reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"SYS_RECVMSG":                       reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"SYS_RENAME":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SYS_RENAMEAT":                      reflect.ValueOf(constant.MakeFromLiteral("323", token.INT, 0)),
		"SYS_REVOKE":                        reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"SYS_RMDIR":                         reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"SYS_SCHED_YIELD":                   reflect.ValueOf(constant.MakeFromLiteral("298", token.INT, 0)),
		"SYS_SELECT":                        reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"SYS_SEMGET":                        reflect.ValueOf(constant.MakeFromLiteral("221", token.INT, 0)),
		"SYS_SEMOP":                         reflect.ValueOf(constant.MakeFromLiteral("290", token.INT, 0)),
		"SYS_SENDMSG":                       reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SYS_SENDSYSLOG":                    reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"SYS_SENDTO":                        reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"SYS_SETEGID":                       reflect.ValueOf(constant.MakeFromLiteral("182", token.INT, 0)),
		"SYS_SETEUID":                       reflect.ValueOf(constant.MakeFromLiteral("183", token.INT, 0)),
		"SYS_SETGID":                        reflect.ValueOf(constant.MakeFromLiteral("181", token.INT, 0)),
		"SYS_SETGROUPS":                     reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"SYS_SETITIMER":                     reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"SYS_SETLOGIN":                      reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"SYS_SETPGID":                       reflect.ValueOf(constant.MakeFromLiteral("82", token.INT, 0)),
		"SYS_SETPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"SYS_SETREGID":                      reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"SYS_SETRESGID":                     reflect.ValueOf(constant.MakeFromLiteral("284", token.INT, 0)),
		"SYS_SETRESUID":                     reflect.ValueOf(constant.MakeFromLiteral("282", token.INT, 0)),
		"SYS_SETREUID":                      reflect.ValueOf(constant.MakeFromLiteral("126", token.INT, 0)),
		"SYS_SETRLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("195", token.INT, 0)),
		"SYS_SETRTABLE":                     reflect.ValueOf(constant.MakeFromLiteral("310", token.INT, 0)),
		"SYS_SETSID":                        reflect.ValueOf(constant.MakeFromLiteral("147", token.INT, 0)),
		"SYS_SETSOCKOPT":                    reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"SYS_SETTIMEOFDAY":                  reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"SYS_SETUID":                        reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"SYS_SHMAT":                         reflect.ValueOf(constant.MakeFromLiteral("228", token.INT, 0)),
		"SYS_SHMCTL":                        reflect.ValueOf(constant.MakeFromLiteral("296", token.INT, 0)),
		"SYS_SHMDT":                         reflect.ValueOf(constant.MakeFromLiteral("230", token.INT, 0)),
		"SYS_SHMGET":                        reflect.ValueOf(constant.MakeFromLiteral("289", token.INT, 0)),
		"SYS_SHUTDOWN":                      reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"SYS_SIGACTION":                     reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"SYS_SIGALTSTACK":                   reflect.ValueOf(constant.MakeFromLiteral("288", token.INT, 0)),
		"SYS_SIGPENDING":                    reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"SYS_SIGPROCMASK":                   reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"SYS_SIGRETURN":                     reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"SYS_SIGSUSPEND":                    reflect.ValueOf(constant.MakeFromLiteral("111", token.INT, 0)),
		"SYS_SOCKET":                        reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"SYS_SOCKETPAIR":                    reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"SYS_STAT":                          reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"SYS_STATFS":                        reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"SYS_SWAPCTL":                       reflect.ValueOf(constant.MakeFromLiteral("193", token.INT, 0)),
		"SYS_SYMLINK":                       reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"SYS_SYMLINKAT":                     reflect.ValueOf(constant.MakeFromLiteral("324", token.INT, 0)),
		"SYS_SYNC":                          reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"SYS_SYSARCH":                       reflect.ValueOf(constant.MakeFromLiteral("165", token.INT, 0)),
		"SYS_TRUNCATE":                      reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"SYS_UMASK":                         reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"SYS_UNLINK":                        reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"SYS_UNLINKAT":                      reflect.ValueOf(constant.MakeFromLiteral("325", token.INT, 0)),
		"SYS_UNMOUNT":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"SYS_UTIMENSAT":                     reflect.ValueOf(constant.MakeFromLiteral("84", token.INT, 0)),
		"SYS_UTIMES":                        reflect.ValueOf(constant.MakeFromLiteral("76", token.INT, 0)),
		"SYS_UTRACE":                        reflect.ValueOf(constant.MakeFromLiteral("209", token.INT, 0)),
		"SYS_VFORK":                         reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"SYS_WAIT4":                         reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"SYS_WRITE":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SYS_WRITEV":                        reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"SYS___GETCWD":                      reflect.ValueOf(constant.MakeFromLiteral("304", token.INT, 0)),
		"SYS___GET_TCB":                     reflect.ValueOf(constant.MakeFromLiteral("330", token.INT, 0)),
		"SYS___SEMCTL":                      reflect.ValueOf(constant.MakeFromLiteral("295", token.INT, 0)),
		"SYS___SET_TCB":                     reflect.ValueOf(constant.MakeFromLiteral("329", token.INT, 0)),
		"SYS___SYSCTL":                      reflect.ValueOf(constant.MakeFromLiteral("202", token.INT, 0)),
		"SYS___TFORK":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SYS___THREXIT":                     reflect.ValueOf(constant.MakeFromLiteral("302", token.INT, 0)),
		"SYS___THRSIGDIVERT":                reflect.ValueOf(constant.MakeFromLiteral("303", token.INT, 0)),
		"SYS___THRSLEEP":                    reflect.ValueOf(constant.MakeFromLiteral("94", token.INT, 0)),
		"SYS___THRWAKEUP":                   reflect.ValueOf(constant.MakeFromLiteral("301", token.INT, 0)),
		"S_IFBLK":                           reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"S_IFCHR":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"S_IFDIR":                           reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"S_IFIFO":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"S_IFLNK":                           reflect.ValueOf(constant.MakeFromLiteral("40960", token.INT, 0)),
		"S_IFMT":                            reflect.ValueOf(constant.MakeFromLiteral("61440", token.INT, 0)),
		"S_IFREG":                           reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"S_IFSOCK":                          reflect.ValueOf(constant.MakeFromLiteral("49152", token.INT, 0)),
		"S_IRUSR":                           reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRWXG":                           reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"S_IRWXO":                           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"S_ISGID":                           reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ISUID":                           reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"S_ISVTX":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_IWUSR":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IXUSR":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"Seek":                              reflect.ValueOf(syscall.Seek),
		"Select":                            reflect.ValueOf(syscall.Select),
		"Sendfile":                          reflect.ValueOf(syscall.Sendfile),
		"Sendmsg":                           reflect.ValueOf(syscall.Sendmsg),
		"SendmsgN":                          reflect.ValueOf(syscall.SendmsgN),
		"Sendto":                            reflect.ValueOf(syscall.Sendto),
		"SetBpf":                            reflect.ValueOf(syscall.SetBpf),
		"SetBpfBuflen":                      reflect.ValueOf(syscall.SetBpfBuflen),
		"SetBpfDatalink":                    reflect.ValueOf(syscall.SetBpfDatalink),
		"SetBpfHeadercmpl":                  reflect.ValueOf(syscall.SetBpfHeadercmpl),
		"SetBpfImmediate":                   reflect.ValueOf(syscall.SetBpfImmediate),
		"SetBpfInterface":                   reflect.ValueOf(syscall.SetBpfInterface),
		"SetBpfPromisc":                     reflect.ValueOf(syscall.SetBpfPromisc),
		"SetBpfTimeout":                     reflect.ValueOf(syscall.SetBpfTimeout),
		"SetKevent":                         reflect.ValueOf(syscall.SetKevent),
		"SetNonblock":                       reflect.ValueOf(syscall.SetNonblock),
		"Setegid":                           reflect.ValueOf(syscall.Setegid),
		"Setenv":                            reflect.ValueOf(syscall.Setenv),
		"Seteuid":                           reflect.ValueOf(syscall.Seteuid),
		"Setgid":                            reflect.ValueOf(syscall.Setgid),
		"Setgroups":                         reflect.ValueOf(syscall.Setgroups),
		"Setlogin":                          reflect.ValueOf(syscall.Setlogin),
		"Setpgid":                           reflect.ValueOf(syscall.Setpgid),
		"Setpriority":                       reflect.ValueOf(syscall.Setpriority),
		"Setregid":                          reflect.ValueOf(syscall.Setregid),
		"Setreuid":                          reflect.ValueOf(syscall.Setreuid),
		"Setrlimit":                         reflect.ValueOf(syscall.Setrlimit),
		"Setsid":                            reflect.ValueOf(syscall.Setsid),
		"SetsockoptByte":                    reflect.ValueOf(syscall.SetsockoptByte),
		"SetsockoptICMPv6Filter":            reflect.ValueOf(syscall.SetsockoptICMPv6Filter),
		"SetsockoptIPMreq":                  reflect.ValueOf(syscall.SetsockoptIPMreq),
		"SetsockoptIPv6Mreq":                reflect.ValueOf(syscall.SetsockoptIPv6Mreq),
		"SetsockoptInet4Addr":               reflect.ValueOf(syscall.SetsockoptInet4Addr),
		"SetsockoptInt":                     reflect.ValueOf(syscall.SetsockoptInt),
		"SetsockoptLinger":                  reflect.ValueOf(syscall.SetsockoptLinger),
		"SetsockoptString":                  reflect.ValueOf(syscall.SetsockoptString),
		"SetsockoptTimeval":                 reflect.ValueOf(syscall.SetsockoptTimeval),
		"Settimeofday":                      reflect.ValueOf(syscall.Settimeofday),
		"Setuid":                            reflect.ValueOf(syscall.Setuid),
		"SizeofBpfHdr":                      reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofBpfInsn":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofBpfProgram":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofBpfStat":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofBpfVersion":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SizeofCmsghdr":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofICMPv6Filter":                reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPMreq":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofIPv6MTUInfo":                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPv6Mreq":                    reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofIfAnnounceMsghdr":            reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"SizeofIfData":                      reflect.ValueOf(constant.MakeFromLiteral("144", token.INT, 0)),
		"SizeofIfMsghdr":                    reflect.ValueOf(constant.MakeFromLiteral("168", token.INT, 0)),
		"SizeofIfaMsghdr":                   reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"SizeofInet6Pktinfo":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofLinger":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofMsghdr":                      reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SizeofRtMetrics":                   reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"SizeofRtMsghdr":                    reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"SizeofSockaddrAny":                 reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"SizeofSockaddrDatalink":            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofSockaddrInet4":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofSockaddrInet6":               reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SizeofSockaddrUnix":                reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"SlicePtrFromStrings":               reflect.ValueOf(syscall.SlicePtrFromStrings),
		"Socket":                            reflect.ValueOf(syscall.Socket),
		"SocketDisableIPv6":                 reflect.ValueOf(&syscall.SocketDisableIPv6).Elem(),
		"Socketpair":                        reflect.ValueOf(syscall.Socketpair),
		"Stat":                              reflect.ValueOf(syscall.Stat),
		"Statfs":                            reflect.ValueOf(syscall.Statfs),
		"Stderr":                            reflect.ValueOf(&syscall.Stderr).Elem(),
		"Stdin":                             reflect.ValueOf(&syscall.Stdin).Elem(),
		"Stdout":                            reflect.ValueOf(&syscall.Stdout).Elem(),
		"StringBytePtr":                     reflect.ValueOf(syscall.StringBytePtr),
		"StringByteSlice":                   reflect.ValueOf(syscall.StringByteSlice),
		"StringSlicePtr":                    reflect.ValueOf(syscall.StringSlicePtr),
		"Symlink":                           reflect.ValueOf(syscall.Symlink),
		"Sync":                              reflect.ValueOf(syscall.Sync),
		"Sysctl":                            reflect.ValueOf(syscall.Sysctl),
		"SysctlUint32":                      reflect.ValueOf(syscall.SysctlUint32),
		"TCIFLUSH":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCIOFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"TCOFLUSH":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_MAXBURST":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_MAXSEG":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_MAXWIN":                        reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"TCP_MAX_SACK":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"TCP_MAX_WINSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"TCP_MD5SIG":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_MSS":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"TCP_NODELAY":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_NOPUSH":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TCP_NSTATES":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"TCP_SACK_ENABLE":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCSAFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCCBRK":                          reflect.ValueOf(constant.MakeFromLiteral("536900730", token.INT, 0)),
		"TIOCCDTR":                          reflect.ValueOf(constant.MakeFromLiteral("536900728", token.INT, 0)),
		"TIOCCONS":                          reflect.ValueOf(constant.MakeFromLiteral("2147775586", token.INT, 0)),
		"TIOCDRAIN":                         reflect.ValueOf(constant.MakeFromLiteral("536900702", token.INT, 0)),
		"TIOCEXCL":                          reflect.ValueOf(constant.MakeFromLiteral("536900621", token.INT, 0)),
		"TIOCEXT":                           reflect.ValueOf(constant.MakeFromLiteral("2147775584", token.INT, 0)),
		"TIOCFLAG_CLOCAL":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCFLAG_CRTSCTS":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCFLAG_MDMBUF":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCFLAG_PPS":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCFLAG_SOFTCAR":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("2147775504", token.INT, 0)),
		"TIOCGETA":                          reflect.ValueOf(constant.MakeFromLiteral("1076655123", token.INT, 0)),
		"TIOCGETD":                          reflect.ValueOf(constant.MakeFromLiteral("1074033690", token.INT, 0)),
		"TIOCGFLAGS":                        reflect.ValueOf(constant.MakeFromLiteral("1074033757", token.INT, 0)),
		"TIOCGPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("1074033783", token.INT, 0)),
		"TIOCGSID":                          reflect.ValueOf(constant.MakeFromLiteral("1074033763", token.INT, 0)),
		"TIOCGTSTAMP":                       reflect.ValueOf(constant.MakeFromLiteral("1074558043", token.INT, 0)),
		"TIOCGWINSZ":                        reflect.ValueOf(constant.MakeFromLiteral("1074295912", token.INT, 0)),
		"TIOCMBIC":                          reflect.ValueOf(constant.MakeFromLiteral("2147775595", token.INT, 0)),
		"TIOCMBIS":                          reflect.ValueOf(constant.MakeFromLiteral("2147775596", token.INT, 0)),
		"TIOCMGET":                          reflect.ValueOf(constant.MakeFromLiteral("1074033770", token.INT, 0)),
		"TIOCMODG":                          reflect.ValueOf(constant.MakeFromLiteral("1074033770", token.INT, 0)),
		"TIOCMODS":                          reflect.ValueOf(constant.MakeFromLiteral("2147775597", token.INT, 0)),
		"TIOCMSET":                          reflect.ValueOf(constant.MakeFromLiteral("2147775597", token.INT, 0)),
		"TIOCM_CAR":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CD":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CTS":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCM_DSR":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TIOCM_DTR":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCM_LE":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCM_RI":                          reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RNG":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RTS":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCM_SR":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCM_ST":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCNOTTY":                         reflect.ValueOf(constant.MakeFromLiteral("536900721", token.INT, 0)),
		"TIOCNXCL":                          reflect.ValueOf(constant.MakeFromLiteral("536900622", token.INT, 0)),
		"TIOCOUTQ":                          reflect.ValueOf(constant.MakeFromLiteral("1074033779", token.INT, 0)),
		"TIOCPKT":                           reflect.ValueOf(constant.MakeFromLiteral("2147775600", token.INT, 0)),
		"TIOCPKT_DATA":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TIOCPKT_DOSTOP":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCPKT_FLUSHREAD":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCPKT_FLUSHWRITE":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCPKT_IOCTL":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCPKT_NOSTOP":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCPKT_START":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCPKT_STOP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCREMOTE":                        reflect.ValueOf(constant.MakeFromLiteral("2147775593", token.INT, 0)),
		"TIOCSBRK":                          reflect.ValueOf(constant.MakeFromLiteral("536900731", token.INT, 0)),
		"TIOCSCTTY":                         reflect.ValueOf(constant.MakeFromLiteral("536900705", token.INT, 0)),
		"TIOCSDTR":                          reflect.ValueOf(constant.MakeFromLiteral("536900729", token.INT, 0)),
		"TIOCSETA":                          reflect.ValueOf(constant.MakeFromLiteral("2150396948", token.INT, 0)),
		"TIOCSETAF":                         reflect.ValueOf(constant.MakeFromLiteral("2150396950", token.INT, 0)),
		"TIOCSETAW":                         reflect.ValueOf(constant.MakeFromLiteral("2150396949", token.INT, 0)),
		"TIOCSETD":                          reflect.ValueOf(constant.MakeFromLiteral("2147775515", token.INT, 0)),
		"TIOCSFLAGS":                        reflect.ValueOf(constant.MakeFromLiteral("2147775580", token.INT, 0)),
		"TIOCSIG":                           reflect.ValueOf(constant.MakeFromLiteral("2147775583", token.INT, 0)),
		"TIOCSPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("2147775606", token.INT, 0)),
		"TIOCSTART":                         reflect.ValueOf(constant.MakeFromLiteral("536900718", token.INT, 0)),
		"TIOCSTAT":                          reflect.ValueOf(constant.MakeFromLiteral("2147775589", token.INT, 0)),
		"TIOCSTI":                           reflect.ValueOf(constant.MakeFromLiteral("2147578994", token.INT, 0)),
		"TIOCSTOP":                          reflect.ValueOf(constant.MakeFromLiteral("536900719", token.INT, 0)),
		"TIOCSTSTAMP":                       reflect.ValueOf(constant.MakeFromLiteral("2148037722", token.INT, 0)),
		"TIOCSWINSZ":                        reflect.ValueOf(constant.MakeFromLiteral("2148037735", token.INT, 0)),
		"TIOCUCNTL":                         reflect.ValueOf(constant.MakeFromLiteral("2147775590", token.INT, 0)),
		"TOSTOP":                            reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"TimespecToNsec":                    reflect.ValueOf(syscall.TimespecToNsec),
		"TimevalToNsec":                     reflect.ValueOf(syscall.TimevalToNsec),
		"Truncate":                          reflect.ValueOf(syscall.Truncate),
		"Umask":                             reflect.ValueOf(syscall.Umask),
		"UnixRights":                        reflect.ValueOf(syscall.UnixRights),
		"Unlink":                            reflect.ValueOf(syscall.Unlink),
		"Unmount":                           reflect.ValueOf(syscall.Unmount),
		"Unsetenv":                          reflect.ValueOf(syscall.Unsetenv),
		"Utimes":                            reflect.ValueOf(syscall.Utimes),
		"UtimesNano":                        reflect.ValueOf(syscall.UtimesNano),
		"VDISCARD":                          reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"VDSUSP":                            reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"VEOF":                              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VEOL":                              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"VEOL2":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"VERASE":                            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"VINTR":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"VKILL":                             reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"VLNEXT":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"VMIN":                              reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"VQUIT":                             reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"VREPRINT":                          reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"VSTART":                            reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"VSTATUS":                           reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"VSTOP":                             reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"VSUSP":                             reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"VTIME":                             reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"VWERASE":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"WALTSIG":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"WCONTINUED":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"WCOREFLAG":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"WNOHANG":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"WUNTRACED":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Wait4":                             reflect.ValueOf(syscall.Wait4),
		"Write":                             reflect.ValueOf(syscall.Write),

		// type definitions
		"BpfHdr":                   reflect.ValueOf((*syscall.BpfHdr)(nil)),
		"BpfInsn":                  reflect.ValueOf((*syscall.BpfInsn)(nil)),
		"BpfProgram":               reflect.ValueOf((*syscall.BpfProgram)(nil)),
		"BpfStat":                  reflect.ValueOf((*syscall.BpfStat)(nil)),
		"BpfTimeval":               reflect.ValueOf((*syscall.BpfTimeval)(nil)),
		"BpfVersion":               reflect.ValueOf((*syscall.BpfVersion)(nil)),
		"Cmsghdr":                  reflect.ValueOf((*syscall.Cmsghdr)(nil)),
		"Conn":                     reflect.ValueOf((*syscall.Conn)(nil)),
		"Credential":               reflect.ValueOf((*syscall.Credential)(nil)),
		"Dirent":                   reflect.ValueOf((*syscall.Dirent)(nil)),
		"Errno":                    reflect.ValueOf((*syscall.Errno)(nil)),
		"FdSet":                    reflect.ValueOf((*syscall.FdSet)(nil)),
		"Flock_t":                  reflect.ValueOf((*syscall.Flock_t)(nil)),
		"Fsid":                     reflect.ValueOf((*syscall.Fsid)(nil)),
		"ICMPv6Filter":             reflect.ValueOf((*syscall.ICMPv6Filter)(nil)),
		"IPMreq":                   reflect.ValueOf((*syscall.IPMreq)(nil)),
		"IPv6MTUInfo":              reflect.ValueOf((*syscall.IPv6MTUInfo)(nil)),
		"IPv6Mreq":                 reflect.ValueOf((*syscall.IPv6Mreq)(nil)),
		"IfAnnounceMsghdr":         reflect.ValueOf((*syscall.IfAnnounceMsghdr)(nil)),
		"IfData":                   reflect.ValueOf((*syscall.IfData)(nil)),
		"IfMsghdr":                 reflect.ValueOf((*syscall.IfMsghdr)(nil)),
		"IfaMsghdr":                reflect.ValueOf((*syscall.IfaMsghdr)(nil)),
		"Inet6Pktinfo":             reflect.ValueOf((*syscall.Inet6Pktinfo)(nil)),
		"InterfaceAddrMessage":     reflect.ValueOf((*syscall.InterfaceAddrMessage)(nil)),
		"InterfaceAnnounceMessage": reflect.ValueOf((*syscall.InterfaceAnnounceMessage)(nil)),
		"InterfaceMessage":         reflect.ValueOf((*syscall.InterfaceMessage)(nil)),
		"Iovec":                    reflect.ValueOf((*syscall.Iovec)(nil)),
		"Kevent_t":                 reflect.ValueOf((*syscall.Kevent_t)(nil)),
		"Linger":                   reflect.ValueOf((*syscall.Linger)(nil)),
		"Mclpool":                  reflect.ValueOf((*syscall.Mclpool)(nil)),
		"Msghdr":                   reflect.ValueOf((*syscall.Msghdr)(nil)),
		"ProcAttr":                 reflect.ValueOf((*syscall.ProcAttr)(nil)),
		"RawConn":                  reflect.ValueOf((*syscall.RawConn)(nil)),
		"RawSockaddr":              reflect.ValueOf((*syscall.RawSockaddr)(nil)),
		"RawSockaddrAny":           reflect.ValueOf((*syscall.RawSockaddrAny)(nil)),
		"RawSockaddrDatalink":      reflect.ValueOf((*syscall.RawSockaddrDatalink)(nil)),
		"RawSockaddrInet4":         reflect.ValueOf((*syscall.RawSockaddrInet4)(nil)),
		"RawSockaddrInet6":         reflect.ValueOf((*syscall.RawSockaddrInet6)(nil)),
		"RawSockaddrUnix":          reflect.ValueOf((*syscall.RawSockaddrUnix)(nil)),
		"Rlimit":                   reflect.ValueOf((*syscall.Rlimit)(nil)),
		"RouteMessage":             reflect.ValueOf((*syscall.RouteMessage)(nil)),
		"RoutingMessage":           reflect.ValueOf((*syscall.RoutingMessage)(nil)),
		"RtMetrics":                reflect.ValueOf((*syscall.RtMetrics)(nil)),
		"RtMsghdr":                 reflect.ValueOf((*syscall.RtMsghdr)(nil)),
		"Rusage":                   reflect.ValueOf((*syscall.Rusage)(nil)),
		"Signal":                   reflect.ValueOf((*syscall.Signal)(nil)),
		"Sockaddr":                 reflect.ValueOf((*syscall.Sockaddr)(nil)),
		"SockaddrDatalink":         reflect.ValueOf((*syscall.SockaddrDatalink)(nil)),
		"SockaddrInet4":            reflect.ValueOf((*syscall.SockaddrInet4)(nil)),
		"SockaddrInet6":            reflect.ValueOf((*syscall.SockaddrInet6)(nil)),
		"SockaddrUnix":             reflect.ValueOf((*syscall.SockaddrUnix)(nil)),
		"SocketControlMessage":     reflect.ValueOf((*syscall.SocketControlMessage)(nil)),
		"Stat_t":                   reflect.ValueOf((*syscall.Stat_t)(nil)),
		"Statfs_t":                 reflect.ValueOf((*syscall.Statfs_t)(nil)),
		"SysProcAttr":              reflect.ValueOf((*syscall.SysProcAttr)(nil)),
		"Termios":                  reflect.ValueOf((*syscall.Termios)(nil)),
		"Timespec":                 reflect.ValueOf((*syscall.Timespec)(nil)),
		"Timeval":                  reflect.ValueOf((*syscall.Timeval)(nil)),
		"WaitStatus":               reflect.ValueOf((*syscall.WaitStatus)(nil)),

		// interface wrapper definitions
		"_Conn":           reflect.ValueOf((*_syscall_Conn)(nil)),
		"_RawConn":        reflect.ValueOf((*_syscall_RawConn)(nil)),
		"_RoutingMessage": reflect.ValueOf((*_syscall_RoutingMessage)(nil)),
		"_Sockaddr":       reflect.ValueOf((*_syscall_Sockaddr)(nil)),
	}
}

// _syscall_Conn is an interface wrapper for Conn type
type _syscall_Conn struct {
	IValue       interface{}
	WSyscallConn func() (syscall.RawConn, error)
}

func (W _syscall_Conn) SyscallConn() (syscall.RawConn, error) { return W.WSyscallConn() }

// _syscall_RawConn is an interface wrapper for RawConn type
type _syscall_RawConn struct {
	IValue   interface{}
	WControl func(f func(fd uintptr)) error
	WRead    func(f func(fd uintptr) (done bool)) error
	WWrite   func(f func(fd uintptr) (done bool)) error
}

func (W _syscall_RawConn) Control(f func(fd uintptr)) error           { return W.WControl(f) }
func (W _syscall_RawConn) Read(f func(fd uintptr) (done bool)) error  { return W.WRead(f) }
func (W _syscall_RawConn) Write(f func(fd uintptr) (done bool)) error { return W.WWrite(f) }

// _syscall_RoutingMessage is an interface wrapper for RoutingMessage type
type _syscall_RoutingMessage struct {
	IValue interface{}
}

// _syscall_Sockaddr is an interface wrapper for Sockaddr type
type _syscall_Sockaddr struct {
	IValue interface{}
}
